######################################################################
#
#  Site Text Indexing Configuration
#
######################################################################
#
# This file is part of GNU EPrints 2.
# 
# Copyright (c) 2000-2004 University of Southampton, UK. SO17 1BJ.
# 
# EPrints 2 is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# EPrints 2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with EPrints 2; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
######################################################################
#
# These values control what words do and don't make it into
# the free text search index. Stemming is allowed : eg. removing 
# "ing" and "s" off the end of word so "looks", "looking" and "look"
# all get indexed as "look". Which is probably helpful.
#
######################################################################
#
# For other languages, the following method is chosen. The text is
# processed keeping letters, digits and hyphens only, breaking at
# difrerent characters. Words longer than the minimal and shorted
# than the maximal length are kept. There will be an "accented" and
# an "unaccented" version. The STOP_WORDS are in the accented vesion.
#
# There is a translation table which contains all chars to be 
# considered. Each line has the following form:
#    'char' => [ 'lower-case', 'latin' ],
# where everything is UTF-8 encoded. Only those chars which are in
# the first field are considered; at other characters the sequence is
# broken. Instead 'char' its 'lower-case' is used in the indexed word;
# furthermore a new word is put together using the 'latin' equivalent.
# The accented word is checked for length, which must be at lest
# MIN_SIZE, and at most MAX_SIZE; also it is checked against the
# given STOP_WORDS.
#

# Minimum size word to normally index.
my $FREETEXT_MIN_WORD_SIZE = 3;

# Maximum size word to index
my $FREETEXT_MAX_WORD_SIZE = 30;

# We use a hash rather than an array for good and bad
# words as we only use these to lookup if words are in
# them or not. If we used arrays and we had lots of words
# it might slow things down.

# Words to never index, despite their length.
my $FREETEXT_STOP_WORDS = {
	"this"=>1,	"are"=>1,	"which"=>1,	"with"=>1,
	"that"=>1,	"can"=>1,	"from"=>1,	"these"=>1,
	"those"=>1,	"the"=>1,	"you"=>1,	"for"=>1,
	"been"=>1,	"have"=>1,	"were"=>1,	"what"=>1,
	"where"=>1,	"is"=>1,	"and"=>1, 	"fnord"=>1,
# ADD FURTHER NATIONAL STOPWORDS HERE
# THESE SHOULD BE ENCODED AS UTF-8
# in Hungarian:
	"tehát"=>1,	"vagy"=>1,	"valamint"=>1,	"meg"=>1,
	"azok"=>1,	"így"=>1,	"ugyanis"=>1,	"két"=>1,
	"ahol"=>1,	"van"=>1,	"vannak"=>1,	"mert"=>1,
	"nem"=>1,	"akkor"=>1,	"azt"=>1,	"ott"=>1,
	"kis"=>1,	"mint"=>1,	"olyan"=>1,	"ilyen"=>1,
	"még"=>1,	"hogy"=>1,	"úgy"=>1,	"minden"=>1,
	"volna"=>1,	"kell"=>1,	"sem"=>1,	"nagy"=>1,
	"pedig"=>1,	"volt"=>1,	"már"=>1,	"itt"=>1,
	"most"=>1,	"egy"=>1,	"csak"=>1,	"ezt"=>1,
	"fel"=>1,	"mit"=>1,	"mikor"=>1,	"hogyan"=>1,
};

# Words to always index, despite their length.
my $FREETEXT_ALWAYS_WORDS = {
		"ok" => 1 
};

# Translation has valuess. The lc(...) should give the lower case
# equivalent, however it does not.
my $UnicodeConv = {
'0' => [ '0', '0'], #0030 DIGIT
'1' => [ '1', '1'], #0031 DIGIT
'2' => [ '2', '2'], #0032 DIGIT
'3' => [ '3', '3'], #0033 DIGIT
'4' => [ '4', '4'], #0034 DIGIT
'5' => [ '5', '5'], #0035 DIGIT
'6' => [ '6', '6'], #0036 DIGIT
'7' => [ '7', '7'], #0037 DIGIT
'8' => [ '8', '8'], #0038 DIGIT
'9' => [ '9', '9'], #0039 DIGIT
'-' => [ '-', '-'], #002D HYPHEN-MINUS
'A' => [ 'a', 'a'], #0041 LATIN CAPITAL LETTER A
'B' => [ 'b', 'b'], #0042 LATIN CAPITAL LETTER B
'C' => [ 'c', 'c'], #0043 LATIN CAPITAL LETTER C
'D' => [ 'd', 'd'], #0044 LATIN CAPITAL LETTER D
'E' => [ 'e', 'e'], #0045 LATIN CAPITAL LETTER E
'F' => [ 'f', 'f'], #0046 LATIN CAPITAL LETTER F
'G' => [ 'g', 'g'], #0047 LATIN CAPITAL LETTER G
'H' => [ 'h', 'h'], #0048 LATIN CAPITAL LETTER H
'I' => [ 'i', 'i'], #0049 LATIN CAPITAL LETTER I
'J' => [ 'j', 'j'], #004A LATIN CAPITAL LETTER J
'K' => [ 'k', 'k'], #004B LATIN CAPITAL LETTER K
'L' => [ 'l', 'l'], #004C LATIN CAPITAL LETTER L
'M' => [ 'm', 'm'], #004D LATIN CAPITAL LETTER M
'N' => [ 'n', 'n'], #004E LATIN CAPITAL LETTER N
'O' => [ 'o', 'o'], #004F LATIN CAPITAL LETTER O
'P' => [ 'p', 'p'], #0050 LATIN CAPITAL LETTER P
'Q' => [ 'q', 'q'], #0051 LATIN CAPITAL LETTER Q
'R' => [ 'r', 'r'], #0052 LATIN CAPITAL LETTER R
'S' => [ 's', 's'], #0053 LATIN CAPITAL LETTER S
'T' => [ 't', 't'], #0054 LATIN CAPITAL LETTER T
'U' => [ 'u', 'u'], #0055 LATIN CAPITAL LETTER U
'V' => [ 'v', 'v'], #0056 LATIN CAPITAL LETTER V
'W' => [ 'w', 'w'], #0057 LATIN CAPITAL LETTER W
'X' => [ 'x', 'x'], #0058 LATIN CAPITAL LETTER X
'Y' => [ 'y', 'y'], #0059 LATIN CAPITAL LETTER Y
'Z' => [ 'z', 'z'], #005A LATIN CAPITAL LETTER Z
'a' => [ 'a', 'a'], #0061 LATIN SMALL LETTER A
'b' => [ 'b', 'b'], #0062 LATIN SMALL LETTER B
'c' => [ 'c', 'c'], #0063 LATIN SMALL LETTER C
'd' => [ 'd', 'd'], #0064 LATIN SMALL LETTER D
'e' => [ 'e', 'e'], #0065 LATIN SMALL LETTER E
'f' => [ 'f', 'f'], #0066 LATIN SMALL LETTER F
'g' => [ 'g', 'g'], #0067 LATIN SMALL LETTER G
'h' => [ 'h', 'h'], #0068 LATIN SMALL LETTER H
'i' => [ 'i', 'i'], #0069 LATIN SMALL LETTER I
'j' => [ 'j', 'j'], #006A LATIN SMALL LETTER J
'k' => [ 'k', 'k'], #006B LATIN SMALL LETTER K
'l' => [ 'l', 'l'], #006C LATIN SMALL LETTER L
'm' => [ 'm', 'm'], #006D LATIN SMALL LETTER M
'n' => [ 'n', 'n'], #006E LATIN SMALL LETTER N
'o' => [ 'o', 'o'], #006F LATIN SMALL LETTER O
'p' => [ 'p', 'p'], #0070 LATIN SMALL LETTER P
'q' => [ 'q', 'q'], #0071 LATIN SMALL LETTER Q
'r' => [ 'r', 'r'], #0072 LATIN SMALL LETTER R
's' => [ 's', 's'], #0073 LATIN SMALL LETTER S
't' => [ 't', 't'], #0074 LATIN SMALL LETTER T
'u' => [ 'u', 'u'], #0075 LATIN SMALL LETTER U
'v' => [ 'v', 'v'], #0076 LATIN SMALL LETTER V
'w' => [ 'w', 'w'], #0077 LATIN SMALL LETTER W
'x' => [ 'x', 'x'], #0078 LATIN SMALL LETTER X
'y' => [ 'y', 'y'], #0079 LATIN SMALL LETTER Y
'z' => [ 'z', 'z'], #007A LATIN SMALL LETTER Z
'À' => [ 'à', 'a'], #00C0 LATIN CAPITAL LETTER A WITH GRAVE
'Á' => [ 'á', 'a'], #00C1 LATIN CAPITAL LETTER A WITH ACUTE
'Â' => [ 'â', 'a'], #00C2 LATIN CAPITAL LETTER A WITH CIRCUMFLEX
'Ã' => [ 'ã', 'a'], #00C3 LATIN CAPITAL LETTER A WITH TILDE
'Ä' => [ 'ä', 'a'], #00C4 LATIN CAPITAL LETTER A WITH DIAERESIS
'Å' => [ 'å', 'a'], #00C5 LATIN CAPITAL LETTER A WITH RING ABOVE
'Æ' => [ 'æ', 'ae'], #00C6 LATIN CAPITAL LETTER AE
'Ç' => [ 'ç', 'c'], #00C7 LATIN CAPITAL LETTER C WITH CEDILLA
'È' => [ 'è', 'e'], #00C8 LATIN CAPITAL LETTER E WITH GRAVE
'É' => [ 'é', 'e'], #00C9 LATIN CAPITAL LETTER E WITH ACUTE
'Ê' => [ 'ê', 'e'], #00CA LATIN CAPITAL LETTER E WITH CIRCUMFLEX
'Ë' => [ 'ë', 'e'], #00CB LATIN CAPITAL LETTER E WITH DIAERESIS
'Ì' => [ 'ì', 'i'], #00CC LATIN CAPITAL LETTER I WITH GRAVE
'Í' => [ 'í', 'i'], #00CD LATIN CAPITAL LETTER I WITH ACUTE
'Î' => [ 'î', 'i'], #00CE LATIN CAPITAL LETTER I WITH CIRCUMFLEX
'Ï' => [ 'ï', 'i'], #00CF LATIN CAPITAL LETTER I WITH DIAERESIS
'Ñ' => [ 'ñ', 'n'], #00D1 LATIN CAPITAL LETTER N WITH TILDE
'Ò' => [ 'ò', 'o'], #00D2 LATIN CAPITAL LETTER O WITH GRAVE
'Ó' => [ 'ó', 'o'], #00D3 LATIN CAPITAL LETTER O WITH ACUTE
'Ô' => [ 'ô', 'o'], #00D4 LATIN CAPITAL LETTER O WITH CIRCUMFLEX
'Õ' => [ 'õ', 'o'], #00D5 LATIN CAPITAL LETTER O WITH TILDE
'Ö' => [ 'ö', 'o'], #00D6 LATIN CAPITAL LETTER O WITH DIAERESIS
'Ø' => [ 'ø', 'o'], #00D8 LATIN CAPITAL LETTER O WITH STROKE
'Ù' => [ 'ù', 'u'], #00D9 LATIN CAPITAL LETTER U WITH GRAVE
'Ú' => [ 'ú', 'u'], #00DA LATIN CAPITAL LETTER U WITH ACUTE
'Û' => [ 'û', 'u'], #00DB LATIN CAPITAL LETTER U WITH CIRCUMFLEX
'Ü' => [ 'ü', 'u'], #00DC LATIN CAPITAL LETTER U WITH DIAERESIS
'Ý' => [ 'ý', 'y'], #00DD LATIN CAPITAL LETTER Y WITH ACUTE
'ß' => [ 'ß', 's'], #00DF LATIN SMALL LETTER SHARP S
'à' => [ 'à', 'a'], #00E0 LATIN SMALL LETTER A WITH GRAVE
'á' => [ 'á', 'a'], #00E1 LATIN SMALL LETTER A WITH ACUTE
'â' => [ 'â', 'a'], #00E2 LATIN SMALL LETTER A WITH CIRCUMFLEX
'ã' => [ 'ã', 'a'], #00E3 LATIN SMALL LETTER A WITH TILDE
'ä' => [ 'ä', 'a'], #00E4 LATIN SMALL LETTER A WITH DIAERESIS
'å' => [ 'å', 'a'], #00E5 LATIN SMALL LETTER A WITH RING ABOVE
'æ' => [ 'æ', 'ae'], #00E6 LATIN SMALL LETTER AE
'ç' => [ 'ç', 'c'], #00E7 LATIN SMALL LETTER C WITH CEDILLA
'è' => [ 'è', 'e'], #00E8 LATIN SMALL LETTER E WITH GRAVE
'é' => [ 'é', 'e'], #00E9 LATIN SMALL LETTER E WITH ACUTE
'ê' => [ 'ê', 'e'], #00EA LATIN SMALL LETTER E WITH CIRCUMFLEX
'ë' => [ 'ë', 'e'], #00EB LATIN SMALL LETTER E WITH DIAERESIS
'ì' => [ 'ì', 'i'], #00EC LATIN SMALL LETTER I WITH GRAVE
'í' => [ 'í', 'i'], #00ED LATIN SMALL LETTER I WITH ACUTE
'î' => [ 'î', 'i'], #00EE LATIN SMALL LETTER I WITH CIRCUMFLEX
'ï' => [ 'ï', 'i'], #00EF LATIN SMALL LETTER I WITH DIAERESIS
'ñ' => [ 'ñ', 'n'], #00F1 LATIN SMALL LETTER N WITH TILDE
'ò' => [ 'ò', 'o'], #00F2 LATIN SMALL LETTER O WITH GRAVE
'ó' => [ 'ó', 'o'], #00F3 LATIN SMALL LETTER O WITH ACUTE
'ô' => [ 'ô', 'o'], #00F4 LATIN SMALL LETTER O WITH CIRCUMFLEX
'õ' => [ 'õ', 'o'], #00F5 LATIN SMALL LETTER O WITH TILDE
'ö' => [ 'ö', 'o'], #00F6 LATIN SMALL LETTER O WITH DIAERESIS
'ø' => [ 'ø', 'o'], #00F8 LATIN SMALL LETTER O WITH STROKE
'ù' => [ 'ù', 'u'], #00F9 LATIN SMALL LETTER U WITH GRAVE
'ú' => [ 'ú', 'u'], #00FA LATIN SMALL LETTER U WITH ACUTE
'û' => [ 'û', 'u'], #00FB LATIN SMALL LETTER U WITH CIRCUMFLEX
'ü' => [ 'ü', 'u'], #00FC LATIN SMALL LETTER U WITH DIAERESIS
'ý' => [ 'ý', 'y'], #00FD LATIN SMALL LETTER Y WITH ACUTE
'ÿ' => [ 'ÿ', 'y'], #00FF LATIN SMALL LETTER Y WITH DIAERESIS
'Ā' => [ 'ā', 'a'], #0100 LATIN CAPITAL LETTER A WITH MACRON
'ā' => [ 'ā', 'a'], #0101 LATIN SMALL LETTER A WITH MACRON
'Ă' => [ 'ă', 'a'], #0102 LATIN CAPITAL LETTER A WITH BREVE
'ă' => [ 'ă', 'a'], #0103 LATIN SMALL LETTER A WITH BREVE
'Ą' => [ 'ą', 'a'], #0104 LATIN CAPITAL LETTER A WITH OGONEK
'ą' => [ 'ą', 'a'], #0105 LATIN SMALL LETTER A WITH OGONEK
'Ć' => [ 'ć', 'c'], #0106 LATIN CAPITAL LETTER C WITH ACUTE
'ć' => [ 'ć', 'c'], #0107 LATIN SMALL LETTER C WITH ACUTE
'Ĉ' => [ 'ĉ', 'c'], #0108 LATIN CAPITAL LETTER C WITH CIRCUMFLEX
'ĉ' => [ 'ĉ', 'c'], #0109 LATIN SMALL LETTER C WITH CIRCUMFLEX
'Ċ' => [ 'ċ', 'c'], #010A LATIN CAPITAL LETTER C WITH DOT ABOVE
'ċ' => [ 'ċ', 'c'], #010B LATIN SMALL LETTER C WITH DOT ABOVE
'Č' => [ 'č', 'c'], #010C LATIN CAPITAL LETTER C WITH CARON
'č' => [ 'č', 'c'], #010D LATIN SMALL LETTER C WITH CARON
'Ď' => [ 'ď', 'd'], #010E LATIN CAPITAL LETTER D WITH CARON
'ď' => [ 'ď', 'd'], #010F LATIN SMALL LETTER D WITH CARON
'Đ' => [ 'đ', 'd'], #0110 LATIN CAPITAL LETTER D WITH STROKE
'đ' => [ 'đ', 'd'], #0111 LATIN SMALL LETTER D WITH STROKE
'Ē' => [ 'ē', 'e'], #0112 LATIN CAPITAL LETTER E WITH MACRON
'ē' => [ 'ē', 'e'], #0113 LATIN SMALL LETTER E WITH MACRON
'Ĕ' => [ 'ĕ', 'e'], #0114 LATIN CAPITAL LETTER E WITH BREVE
'ĕ' => [ 'ĕ', 'e'], #0115 LATIN SMALL LETTER E WITH BREVE
'Ė' => [ 'ė', 'e'], #0116 LATIN CAPITAL LETTER E WITH DOT ABOVE
'ė' => [ 'ė', 'e'], #0117 LATIN SMALL LETTER E WITH DOT ABOVE
'Ę' => [ 'ę', 'e'], #0118 LATIN CAPITAL LETTER E WITH OGONEK
'ę' => [ 'ę', 'e'], #0119 LATIN SMALL LETTER E WITH OGONEK
'Ě' => [ 'ě', 'e'], #011A LATIN CAPITAL LETTER E WITH CARON
'ě' => [ 'ě', 'e'], #011B LATIN SMALL LETTER E WITH CARON
'Ĝ' => [ 'ĝ', 'g'], #011C LATIN CAPITAL LETTER G WITH CIRCUMFLEX
'ĝ' => [ 'ĝ', 'g'], #011D LATIN SMALL LETTER G WITH CIRCUMFLEX
'Ğ' => [ 'ğ', 'g'], #011E LATIN CAPITAL LETTER G WITH BREVE
'ğ' => [ 'ğ', 'g'], #011F LATIN SMALL LETTER G WITH BREVE
'Ġ' => [ 'ġ', 'g'], #0120 LATIN CAPITAL LETTER G WITH DOT ABOVE
'ġ' => [ 'ġ', 'g'], #0121 LATIN SMALL LETTER G WITH DOT ABOVE
'Ģ' => [ 'ģ', 'g'], #0122 LATIN CAPITAL LETTER G WITH CEDILLA
'ģ' => [ 'ģ', 'g'], #0123 LATIN SMALL LETTER G WITH CEDILLA
'Ĥ' => [ 'ĥ', 'h'], #0124 LATIN CAPITAL LETTER H WITH CIRCUMFLEX
'ĥ' => [ 'ĥ', 'h'], #0125 LATIN SMALL LETTER H WITH CIRCUMFLEX
'Ħ' => [ 'ħ', 'h'], #0126 LATIN CAPITAL LETTER H WITH STROKE
'ħ' => [ 'ħ', 'h'], #0127 LATIN SMALL LETTER H WITH STROKE
'Ĩ' => [ 'ĩ', 'i'], #0128 LATIN CAPITAL LETTER I WITH TILDE
'ĩ' => [ 'ĩ', 'i'], #0129 LATIN SMALL LETTER I WITH TILDE
'Ī' => [ 'ī', 'i'], #012A LATIN CAPITAL LETTER I WITH MACRON
'ī' => [ 'ī', 'i'], #012B LATIN SMALL LETTER I WITH MACRON
'Ĭ' => [ 'ĭ', 'i'], #012C LATIN CAPITAL LETTER I WITH BREVE
'ĭ' => [ 'ĭ', 'i'], #012D LATIN SMALL LETTER I WITH BREVE
'Į' => [ 'į', 'i'], #012E LATIN CAPITAL LETTER I WITH OGONEK
'į' => [ 'į', 'i'], #012F LATIN SMALL LETTER I WITH OGONEK
'İ' => [ 'i', 'i'], #0130 LATIN CAPITAL LETTER I WITH DOT ABOVE
'ı' => [ 'ı', 'i'], #0131 LATIN SMALL LETTER DOTLESS I
'Ĳ' => [ 'ĳ', 'ij'], #0132 LATIN CAPITAL LIGATURE IJ
'ĳ' => [ 'ĳ', 'ij'], #0133 LATIN SMALL LIGATURE IJ
'Ĵ' => [ 'ĵ', 'j'], #0134 LATIN CAPITAL LETTER J WITH CIRCUMFLEX
'ĵ' => [ 'ĵ', 'j'], #0135 LATIN SMALL LETTER J WITH CIRCUMFLEX
'Ķ' => [ 'ķ', 'k'], #0136 LATIN CAPITAL LETTER K WITH CEDILLA
'ķ' => [ 'ķ', 'k'], #0137 LATIN SMALL LETTER K WITH CEDILLA
'Ĺ' => [ 'ĺ', 'l'], #0139 LATIN CAPITAL LETTER L WITH ACUTE
'ĺ' => [ 'ĺ', 'l'], #013A LATIN SMALL LETTER L WITH ACUTE
'Ļ' => [ 'ļ', 'l'], #013B LATIN CAPITAL LETTER L WITH CEDILLA
'ļ' => [ 'ļ', 'l'], #013C LATIN SMALL LETTER L WITH CEDILLA
'Ľ' => [ 'ľ', 'l'], #013D LATIN CAPITAL LETTER L WITH CARON
'ľ' => [ 'ľ', 'l'], #013E LATIN SMALL LETTER L WITH CARON
'Ŀ' => [ 'ŀ', 'l'], #013F LATIN CAPITAL LETTER L WITH MIDDLE DOT
'ŀ' => [ 'ŀ', 'l'], #0140 LATIN SMALL LETTER L WITH MIDDLE DOT
'Ł' => [ 'ł', 'l'], #0141 LATIN CAPITAL LETTER L WITH STROKE
'ł' => [ 'ł', 'l'], #0142 LATIN SMALL LETTER L WITH STROKE
'Ń' => [ 'ń', 'n'], #0143 LATIN CAPITAL LETTER N WITH ACUTE
'ń' => [ 'ń', 'n'], #0144 LATIN SMALL LETTER N WITH ACUTE
'Ņ' => [ 'ņ', 'n'], #0145 LATIN CAPITAL LETTER N WITH CEDILLA
'ņ' => [ 'ņ', 'n'], #0146 LATIN SMALL LETTER N WITH CEDILLA
'Ň' => [ 'ň', 'n'], #0147 LATIN CAPITAL LETTER N WITH CARON
'ň' => [ 'ň', 'n'], #0148 LATIN SMALL LETTER N WITH CARON
'ŉ' => [ 'ŉ', 'n'], #0149 LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
'Ō' => [ 'ō', 'o'], #014C LATIN CAPITAL LETTER O WITH MACRON
'ō' => [ 'ō', 'o'], #014D LATIN SMALL LETTER O WITH MACRON
'Ŏ' => [ 'ŏ', 'o'], #014E LATIN CAPITAL LETTER O WITH BREVE
'ŏ' => [ 'ŏ', 'o'], #014F LATIN SMALL LETTER O WITH BREVE
'Ő' => [ 'ő', 'o'], #0150 LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
'ő' => [ 'ő', 'o'], #0151 LATIN SMALL LETTER O WITH DOUBLE ACUTE
'Œ' => [ 'œ', 'oe'], #0152 LATIN CAPITAL LIGATURE OE
'œ' => [ 'œ', 'oe'], #0153 LATIN SMALL LIGATURE OE
'Ŕ' => [ 'ŕ', 'r'], #0154 LATIN CAPITAL LETTER R WITH ACUTE
'ŕ' => [ 'ŕ', 'r'], #0155 LATIN SMALL LETTER R WITH ACUTE
'Ŗ' => [ 'ŗ', 'r'], #0156 LATIN CAPITAL LETTER R WITH CEDILLA
'ŗ' => [ 'ŗ', 'r'], #0157 LATIN SMALL LETTER R WITH CEDILLA
'Ř' => [ 'ř', 'r'], #0158 LATIN CAPITAL LETTER R WITH CARON
'ř' => [ 'ř', 'r'], #0159 LATIN SMALL LETTER R WITH CARON
'Ś' => [ 'ś', 's'], #015A LATIN CAPITAL LETTER S WITH ACUTE
'ś' => [ 'ś', 's'], #015B LATIN SMALL LETTER S WITH ACUTE
'Ŝ' => [ 'ŝ', 's'], #015C LATIN CAPITAL LETTER S WITH CIRCUMFLEX
'ŝ' => [ 'ŝ', 's'], #015D LATIN SMALL LETTER S WITH CIRCUMFLEX
'Ş' => [ 'ş', 's'], #015E LATIN CAPITAL LETTER S WITH CEDILLA
'ş' => [ 'ş', 's'], #015F LATIN SMALL LETTER S WITH CEDILLA
'Š' => [ 'š', 's'], #0160 LATIN CAPITAL LETTER S WITH CARON
'š' => [ 'š', 's'], #0161 LATIN SMALL LETTER S WITH CARON
'Ţ' => [ 'ţ', 't'], #0162 LATIN CAPITAL LETTER T WITH CEDILLA
'ţ' => [ 'ţ', 't'], #0163 LATIN SMALL LETTER T WITH CEDILLA
'Ť' => [ 'ť', 't'], #0164 LATIN CAPITAL LETTER T WITH CARON
'ť' => [ 'ť', 't'], #0165 LATIN SMALL LETTER T WITH CARON
'Ŧ' => [ 'ŧ', 't'], #0166 LATIN CAPITAL LETTER T WITH STROKE
'ŧ' => [ 'ŧ', 't'], #0167 LATIN SMALL LETTER T WITH STROKE
'Ũ' => [ 'ũ', 'u'], #0168 LATIN CAPITAL LETTER U WITH TILDE
'ũ' => [ 'ũ', 'u'], #0169 LATIN SMALL LETTER U WITH TILDE
'Ū' => [ 'ū', 'u'], #016A LATIN CAPITAL LETTER U WITH MACRON
'ū' => [ 'ū', 'u'], #016B LATIN SMALL LETTER U WITH MACRON
'Ŭ' => [ 'ŭ', 'u'], #016C LATIN CAPITAL LETTER U WITH BREVE
'ŭ' => [ 'ŭ', 'u'], #016D LATIN SMALL LETTER U WITH BREVE
'Ů' => [ 'ů', 'u'], #016E LATIN CAPITAL LETTER U WITH RING ABOVE
'ů' => [ 'ů', 'u'], #016F LATIN SMALL LETTER U WITH RING ABOVE
'Ű' => [ 'ű', 'u'], #0170 LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
'ű' => [ 'ű', 'u'], #0171 LATIN SMALL LETTER U WITH DOUBLE ACUTE
'Ų' => [ 'ų', 'u'], #0172 LATIN CAPITAL LETTER U WITH OGONEK
'ų' => [ 'ų', 'u'], #0173 LATIN SMALL LETTER U WITH OGONEK
'Ŵ' => [ 'ŵ', 'w'], #0174 LATIN CAPITAL LETTER W WITH CIRCUMFLEX
'ŵ' => [ 'ŵ', 'w'], #0175 LATIN SMALL LETTER W WITH CIRCUMFLEX
'Ŷ' => [ 'ŷ', 'y'], #0176 LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
'ŷ' => [ 'ŷ', 'y'], #0177 LATIN SMALL LETTER Y WITH CIRCUMFLEX
'Ÿ' => [ 'ÿ', 'y'], #0178 LATIN CAPITAL LETTER Y WITH DIAERESIS
'Ź' => [ 'ź', 'z'], #0179 LATIN CAPITAL LETTER Z WITH ACUTE
'ź' => [ 'ź', 'z'], #017A LATIN SMALL LETTER Z WITH ACUTE
'Ż' => [ 'ż', 'z'], #017B LATIN CAPITAL LETTER Z WITH DOT ABOVE
'ż' => [ 'ż', 'z'], #017C LATIN SMALL LETTER Z WITH DOT ABOVE
'Ž' => [ 'ž', 'z'], #017D LATIN CAPITAL LETTER Z WITH CARON
'ž' => [ 'ž', 'z'], #017E LATIN SMALL LETTER Z WITH CARON
'ſ' => [ 'ſ', 's'], #017F LATIN SMALL LETTER LONG S
'ƀ' => [ 'ƀ', 'b'], #0180 LATIN SMALL LETTER B WITH STROKE
'Ɓ' => [ 'ɓ', 'b'], #0181 LATIN CAPITAL LETTER B WITH HOOK
'Ƃ' => [ 'ƃ', 'b'], #0182 LATIN CAPITAL LETTER B WITH TOPBAR
'ƃ' => [ 'ƃ', 'b'], #0183 LATIN SMALL LETTER B WITH TOPBAR
'Ɔ' => [ 'ɔ', 'o'], #0186 LATIN CAPITAL LETTER OPEN O
'Ƈ' => [ 'ƈ', 'c'], #0187 LATIN CAPITAL LETTER C WITH HOOK
'ƈ' => [ 'ƈ', 'c'], #0188 LATIN SMALL LETTER C WITH HOOK
'Ɖ' => [ 'ɖ', 'd'], #0189 LATIN CAPITAL LETTER AFRICAN D
'Ɗ' => [ 'ɗ', 'd'], #018A LATIN CAPITAL LETTER D WITH HOOK
'Ƌ' => [ 'ƌ', 'd'], #018B LATIN CAPITAL LETTER D WITH TOPBAR
'ƌ' => [ 'ƌ', 'd'], #018C LATIN SMALL LETTER D WITH TOPBAR
'Ǝ' => [ 'ǝ', 'e'], #018E LATIN CAPITAL LETTER REVERSED E
'Ɛ' => [ 'ɛ', 'e'], #0190 LATIN CAPITAL LETTER OPEN E
'Ƒ' => [ 'ƒ', 'f'], #0191 LATIN CAPITAL LETTER F WITH HOOK
'ƒ' => [ 'ƒ', 'f'], #0192 LATIN SMALL LETTER F WITH HOOK
'Ɠ' => [ 'ɠ', 'g'], #0193 LATIN CAPITAL LETTER G WITH HOOK
'ƕ' => [ 'ƕ', 'hv'], #0195 LATIN SMALL LETTER HV
'Ɨ' => [ 'ɨ', 'i'], #0197 LATIN CAPITAL LETTER I WITH STROKE
'Ƙ' => [ 'ƙ', 'k'], #0198 LATIN CAPITAL LETTER K WITH HOOK
'ƙ' => [ 'ƙ', 'k'], #0199 LATIN SMALL LETTER K WITH HOOK
'ƚ' => [ 'ƚ', 'l'], #019A LATIN SMALL LETTER L WITH BAR
'Ɯ' => [ 'ɯ', 'm'], #019C LATIN CAPITAL LETTER TURNED M
'Ɲ' => [ 'ɲ', 'n'], #019D LATIN CAPITAL LETTER N WITH LEFT HOOK
'ƞ' => [ 'ƞ', 'n'], #019E LATIN SMALL LETTER N WITH LONG RIGHT LEG
'Ɵ' => [ 'ɵ', 'o'], #019F LATIN CAPITAL LETTER O WITH MIDDLE TILDE
'Ơ' => [ 'ơ', 'o'], #01A0 LATIN CAPITAL LETTER O WITH HORN
'ơ' => [ 'ơ', 'o'], #01A1 LATIN SMALL LETTER O WITH HORN
'Ƣ' => [ 'ƣ', 'oi'], #01A2 LATIN CAPITAL LETTER OI
'ƣ' => [ 'ƣ', 'oi'], #01A3 LATIN SMALL LETTER OI
'Ƥ' => [ 'ƥ', 'p'], #01A4 LATIN CAPITAL LETTER P WITH HOOK
'ƥ' => [ 'ƥ', 'p'], #01A5 LATIN SMALL LETTER P WITH HOOK
'Ʀ' => [ 'ʀ', 'yr'], #01A6 LATIN LETTER YR
'ƫ' => [ 'ƫ', 't'], #01AB LATIN SMALL LETTER T WITH PALATAL HOOK
'Ƭ' => [ 'ƭ', 't'], #01AC LATIN CAPITAL LETTER T WITH HOOK
'ƭ' => [ 'ƭ', 't'], #01AD LATIN SMALL LETTER T WITH HOOK
'Ʈ' => [ 'ʈ', 't'], #01AE LATIN CAPITAL LETTER T WITH RETROFLEX HOOK
'Ư' => [ 'ư', 'u'], #01AF LATIN CAPITAL LETTER U WITH HORN
'ư' => [ 'ư', 'u'], #01B0 LATIN SMALL LETTER U WITH HORN
'Ʋ' => [ 'ʋ', 'v'], #01B2 LATIN CAPITAL LETTER V WITH HOOK
'Ƴ' => [ 'ƴ', 'y'], #01B3 LATIN CAPITAL LETTER Y WITH HOOK
'ƴ' => [ 'ƴ', 'y'], #01B4 LATIN SMALL LETTER Y WITH HOOK
'Ƶ' => [ 'ƶ', 'z'], #01B5 LATIN CAPITAL LETTER Z WITH STROKE
'ƶ' => [ 'ƶ', 'z'], #01B6 LATIN SMALL LETTER Z WITH STROKE
'Ǆ' => [ 'ǆ', 'dz'], #01C4 LATIN CAPITAL LETTER DZ WITH CARON
'ǅ' => [ 'ǆ', 'dz'], #01C5 LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON
'ǆ' => [ 'ǆ', 'dz'], #01C6 LATIN SMALL LETTER DZ WITH CARON
'Ǉ' => [ 'ǉ', 'lj'], #01C7 LATIN CAPITAL LETTER LJ
'ǈ' => [ 'ǉ', 'lj'], #01C8 LATIN CAPITAL LETTER L WITH SMALL LETTER J
'ǉ' => [ 'ǉ', 'lj'], #01C9 LATIN SMALL LETTER LJ
'Ǌ' => [ 'ǌ', 'nj'], #01CA LATIN CAPITAL LETTER NJ
'ǋ' => [ 'ǌ', 'nj'], #01CB LATIN CAPITAL LETTER N WITH SMALL LETTER J
'ǌ' => [ 'ǌ', 'nj'], #01CC LATIN SMALL LETTER NJ
'Ǎ' => [ 'ǎ', 'a'], #01CD LATIN CAPITAL LETTER A WITH CARON
'ǎ' => [ 'ǎ', 'a'], #01CE LATIN SMALL LETTER A WITH CARON
'Ǐ' => [ 'ǐ', 'i'], #01CF LATIN CAPITAL LETTER I WITH CARON
'ǐ' => [ 'ǐ', 'i'], #01D0 LATIN SMALL LETTER I WITH CARON
'Ǒ' => [ 'ǒ', 'o'], #01D1 LATIN CAPITAL LETTER O WITH CARON
'ǒ' => [ 'ǒ', 'o'], #01D2 LATIN SMALL LETTER O WITH CARON
'Ǔ' => [ 'ǔ', 'u'], #01D3 LATIN CAPITAL LETTER U WITH CARON
'ǔ' => [ 'ǔ', 'u'], #01D4 LATIN SMALL LETTER U WITH CARON
'Ǖ' => [ 'ǖ', 'u'], #01D5 LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
'ǖ' => [ 'ǖ', 'u'], #01D6 LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
'Ǘ' => [ 'ǘ', 'u'], #01D7 LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
'ǘ' => [ 'ǘ', 'u'], #01D8 LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
'Ǚ' => [ 'ǚ', 'u'], #01D9 LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
'ǚ' => [ 'ǚ', 'u'], #01DA LATIN SMALL LETTER U WITH DIAERESIS AND CARON
'Ǜ' => [ 'ǜ', 'u'], #01DB LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
'ǜ' => [ 'ǜ', 'u'], #01DC LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
'ǝ' => [ 'ǝ', 'e'], #01DD LATIN SMALL LETTER TURNED E
'Ǟ' => [ 'ǟ', 'a'], #01DE LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
'ǟ' => [ 'ǟ', 'a'], #01DF LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
'Ǡ' => [ 'ǡ', 'a'], #01E0 LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON
'ǡ' => [ 'ǡ', 'a'], #01E1 LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON
'Ǣ' => [ 'ǣ', 'ae'], #01E2 LATIN CAPITAL LETTER AE WITH MACRON
'ǣ' => [ 'ǣ', 'ae'], #01E3 LATIN SMALL LETTER AE WITH MACRON
'Ǥ' => [ 'ǥ', 'g'], #01E4 LATIN CAPITAL LETTER G WITH STROKE
'ǥ' => [ 'ǥ', 'g'], #01E5 LATIN SMALL LETTER G WITH STROKE
'Ǧ' => [ 'ǧ', 'g'], #01E6 LATIN CAPITAL LETTER G WITH CARON
'ǧ' => [ 'ǧ', 'g'], #01E7 LATIN SMALL LETTER G WITH CARON
'Ǩ' => [ 'ǩ', 'k'], #01E8 LATIN CAPITAL LETTER K WITH CARON
'ǩ' => [ 'ǩ', 'k'], #01E9 LATIN SMALL LETTER K WITH CARON
'Ǫ' => [ 'ǫ', 'o'], #01EA LATIN CAPITAL LETTER O WITH OGONEK
'ǫ' => [ 'ǫ', 'o'], #01EB LATIN SMALL LETTER O WITH OGONEK
'Ǭ' => [ 'ǭ', 'o'], #01EC LATIN CAPITAL LETTER O WITH OGONEK AND MACRON
'ǭ' => [ 'ǭ', 'o'], #01ED LATIN SMALL LETTER O WITH OGONEK AND MACRON
'ǰ' => [ 'ǰ', 'j'], #01F0 LATIN SMALL LETTER J WITH CARON
'Ǳ' => [ 'ǳ', 'dz'], #01F1 LATIN CAPITAL LETTER DZ
'ǲ' => [ 'ǳ', 'dz'], #01F2 LATIN CAPITAL LETTER D WITH SMALL LETTER Z
'ǳ' => [ 'ǳ', 'dz'], #01F3 LATIN SMALL LETTER DZ
'Ǵ' => [ 'ǵ', 'g'], #01F4 LATIN CAPITAL LETTER G WITH ACUTE
'ǵ' => [ 'ǵ', 'g'], #01F5 LATIN SMALL LETTER G WITH ACUTE
'Ǹ' => [ 'ǹ', 'n'], #01F8 LATIN CAPITAL LETTER N WITH GRAVE
'ǹ' => [ 'ǹ', 'n'], #01F9 LATIN SMALL LETTER N WITH GRAVE
'Ǻ' => [ 'ǻ', 'a'], #01FA LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
'ǻ' => [ 'ǻ', 'a'], #01FB LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
'Ǽ' => [ 'ǽ', 'ae'], #01FC LATIN CAPITAL LETTER AE WITH ACUTE
'ǽ' => [ 'ǽ', 'ae'], #01FD LATIN SMALL LETTER AE WITH ACUTE
'Ǿ' => [ 'ǿ', 'o'], #01FE LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
'ǿ' => [ 'ǿ', 'o'], #01FF LATIN SMALL LETTER O WITH STROKE AND ACUTE
'Ȁ' => [ 'ȁ', 'a'], #0200 LATIN CAPITAL LETTER A WITH DOUBLE GRAVE
'ȁ' => [ 'ȁ', 'a'], #0201 LATIN SMALL LETTER A WITH DOUBLE GRAVE
'Ȃ' => [ 'ȃ', 'a'], #0202 LATIN CAPITAL LETTER A WITH INVERTED BREVE
'ȃ' => [ 'ȃ', 'a'], #0203 LATIN SMALL LETTER A WITH INVERTED BREVE
'Ȅ' => [ 'ȅ', 'e'], #0204 LATIN CAPITAL LETTER E WITH DOUBLE GRAVE
'ȅ' => [ 'ȅ', 'e'], #0205 LATIN SMALL LETTER E WITH DOUBLE GRAVE
'Ȇ' => [ 'ȇ', 'e'], #0206 LATIN CAPITAL LETTER E WITH INVERTED BREVE
'ȇ' => [ 'ȇ', 'e'], #0207 LATIN SMALL LETTER E WITH INVERTED BREVE
'Ȉ' => [ 'ȉ', 'i'], #0208 LATIN CAPITAL LETTER I WITH DOUBLE GRAVE
'ȉ' => [ 'ȉ', 'i'], #0209 LATIN SMALL LETTER I WITH DOUBLE GRAVE
'Ȋ' => [ 'ȋ', 'i'], #020A LATIN CAPITAL LETTER I WITH INVERTED BREVE
'ȋ' => [ 'ȋ', 'i'], #020B LATIN SMALL LETTER I WITH INVERTED BREVE
'Ȍ' => [ 'ȍ', 'o'], #020C LATIN CAPITAL LETTER O WITH DOUBLE GRAVE
'ȍ' => [ 'ȍ', 'o'], #020D LATIN SMALL LETTER O WITH DOUBLE GRAVE
'Ȏ' => [ 'ȏ', 'o'], #020E LATIN CAPITAL LETTER O WITH INVERTED BREVE
'ȏ' => [ 'ȏ', 'o'], #020F LATIN SMALL LETTER O WITH INVERTED BREVE
'Ȑ' => [ 'ȑ', 'r'], #0210 LATIN CAPITAL LETTER R WITH DOUBLE GRAVE
'ȑ' => [ 'ȑ', 'r'], #0211 LATIN SMALL LETTER R WITH DOUBLE GRAVE
'Ȓ' => [ 'ȓ', 'r'], #0212 LATIN CAPITAL LETTER R WITH INVERTED BREVE
'ȓ' => [ 'ȓ', 'r'], #0213 LATIN SMALL LETTER R WITH INVERTED BREVE
'Ȕ' => [ 'ȕ', 'u'], #0214 LATIN CAPITAL LETTER U WITH DOUBLE GRAVE
'ȕ' => [ 'ȕ', 'u'], #0215 LATIN SMALL LETTER U WITH DOUBLE GRAVE
'Ȗ' => [ 'ȗ', 'u'], #0216 LATIN CAPITAL LETTER U WITH INVERTED BREVE
'ȗ' => [ 'ȗ', 'u'], #0217 LATIN SMALL LETTER U WITH INVERTED BREVE
'Ș' => [ 'ș', 's'], #0218 LATIN CAPITAL LETTER S WITH COMMA BELOW
'ș' => [ 'ș', 's'], #0219 LATIN SMALL LETTER S WITH COMMA BELOW
'Ț' => [ 'ț', 't'], #021A LATIN CAPITAL LETTER T WITH COMMA BELOW
'ț' => [ 'ț', 't'], #021B LATIN SMALL LETTER T WITH COMMA BELOW
'Ȟ' => [ 'ȟ', 'h'], #021E LATIN CAPITAL LETTER H WITH CARON
'ȟ' => [ 'ȟ', 'h'], #021F LATIN SMALL LETTER H WITH CARON
'Ƞ' => [ 'ƞ', 'n'], #0220 LATIN CAPITAL LETTER N WITH LONG RIGHT LEG
'ȡ' => [ 'ȡ', 'd'], #0221 LATIN SMALL LETTER D WITH CURL
'Ȣ' => [ 'ȣ', 'ou'], #0222 LATIN CAPITAL LETTER OU
'ȣ' => [ 'ȣ', 'ou'], #0223 LATIN SMALL LETTER OU
'Ȥ' => [ 'ȥ', 'z'], #0224 LATIN CAPITAL LETTER Z WITH HOOK
'ȥ' => [ 'ȥ', 'z'], #0225 LATIN SMALL LETTER Z WITH HOOK
'Ȧ' => [ 'ȧ', 'a'], #0226 LATIN CAPITAL LETTER A WITH DOT ABOVE
'ȧ' => [ 'ȧ', 'a'], #0227 LATIN SMALL LETTER A WITH DOT ABOVE
'Ȩ' => [ 'ȩ', 'e'], #0228 LATIN CAPITAL LETTER E WITH CEDILLA
'ȩ' => [ 'ȩ', 'e'], #0229 LATIN SMALL LETTER E WITH CEDILLA
'Ȫ' => [ 'ȫ', 'o'], #022A LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
'ȫ' => [ 'ȫ', 'o'], #022B LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
'Ȭ' => [ 'ȭ', 'o'], #022C LATIN CAPITAL LETTER O WITH TILDE AND MACRON
'ȭ' => [ 'ȭ', 'o'], #022D LATIN SMALL LETTER O WITH TILDE AND MACRON
'Ȯ' => [ 'ȯ', 'o'], #022E LATIN CAPITAL LETTER O WITH DOT ABOVE
'ȯ' => [ 'ȯ', 'o'], #022F LATIN SMALL LETTER O WITH DOT ABOVE
'Ȱ' => [ 'ȱ', 'o'], #0230 LATIN CAPITAL LETTER O WITH DOT ABOVE AND MACRON
'ȱ' => [ 'ȱ', 'o'], #0231 LATIN SMALL LETTER O WITH DOT ABOVE AND MACRON
'Ȳ' => [ 'ȳ', 'y'], #0232 LATIN CAPITAL LETTER Y WITH MACRON
'ȳ' => [ 'ȳ', 'y'], #0233 LATIN SMALL LETTER Y WITH MACRON
'ȴ' => [ 'ȴ', 'l'], #0234 LATIN SMALL LETTER L WITH CURL
'ȵ' => [ 'ȵ', 'n'], #0235 LATIN SMALL LETTER N WITH CURL
'ȶ' => [ 'ȶ', 't'], #0236 LATIN SMALL LETTER T WITH CURL
'ɐ' => [ 'ɐ', 'a'], #0250 LATIN SMALL LETTER TURNED A
'ɓ' => [ 'ɓ', 'b'], #0253 LATIN SMALL LETTER B WITH HOOK
'ɔ' => [ 'ɔ', 'o'], #0254 LATIN SMALL LETTER OPEN O
'ɕ' => [ 'ɕ', 'c'], #0255 LATIN SMALL LETTER C WITH CURL
'ɖ' => [ 'ɖ', 'd'], #0256 LATIN SMALL LETTER D WITH TAIL
'ɗ' => [ 'ɗ', 'd'], #0257 LATIN SMALL LETTER D WITH HOOK
'ɘ' => [ 'ɘ', 'e'], #0258 LATIN SMALL LETTER REVERSED E
'ɛ' => [ 'ɛ', 'e'], #025B LATIN SMALL LETTER OPEN E
'ɜ' => [ 'ɜ', 'e'], #025C LATIN SMALL LETTER REVERSED OPEN E
'ɝ' => [ 'ɝ', 'e'], #025D LATIN SMALL LETTER REVERSED OPEN E WITH HOOK
'ɞ' => [ 'ɞ', 'e'], #025E LATIN SMALL LETTER CLOSED REVERSED OPEN E
'ɟ' => [ 'ɟ', 'j'], #025F LATIN SMALL LETTER DOTLESS J WITH STROKE
'ɠ' => [ 'ɠ', 'g'], #0260 LATIN SMALL LETTER G WITH HOOK
'ɡ' => [ 'ɡ', 'g'], #0261 LATIN SMALL LETTER SCRIPT G
'ɢ' => [ 'ɢ', 'g'], #0262 LATIN LETTER SMALL CAPITAL G
'ɥ' => [ 'ɥ', 'h'], #0265 LATIN SMALL LETTER TURNED H
'ɦ' => [ 'ɦ', 'h'], #0266 LATIN SMALL LETTER H WITH HOOK
'ɨ' => [ 'ɨ', 'i'], #0268 LATIN SMALL LETTER I WITH STROKE
'ɪ' => [ 'ɪ', 'i'], #026A LATIN LETTER SMALL CAPITAL I
'ɫ' => [ 'ɫ', 'l'], #026B LATIN SMALL LETTER L WITH MIDDLE TILDE
'ɬ' => [ 'ɬ', 'l'], #026C LATIN SMALL LETTER L WITH BELT
'ɭ' => [ 'ɭ', 'l'], #026D LATIN SMALL LETTER L WITH RETROFLEX HOOK
'ɯ' => [ 'ɯ', 'm'], #026F LATIN SMALL LETTER TURNED M
'ɰ' => [ 'ɰ', 'm'], #0270 LATIN SMALL LETTER TURNED M WITH LONG LEG
'ɱ' => [ 'ɱ', 'm'], #0271 LATIN SMALL LETTER M WITH HOOK
'ɲ' => [ 'ɲ', 'n'], #0272 LATIN SMALL LETTER N WITH LEFT HOOK
'ɳ' => [ 'ɳ', 'n'], #0273 LATIN SMALL LETTER N WITH RETROFLEX HOOK
'ɴ' => [ 'ɴ', 'n'], #0274 LATIN LETTER SMALL CAPITAL N
'ɵ' => [ 'ɵ', 'o'], #0275 LATIN SMALL LETTER BARRED O
'ɶ' => [ 'ɶ', 'oe'], #0276 LATIN LETTER SMALL CAPITAL OE
'ɹ' => [ 'ɹ', 'r'], #0279 LATIN SMALL LETTER TURNED R
'ɺ' => [ 'ɺ', 'r'], #027A LATIN SMALL LETTER TURNED R WITH LONG LEG
'ɻ' => [ 'ɻ', 'r'], #027B LATIN SMALL LETTER TURNED R WITH HOOK
'ɼ' => [ 'ɼ', 'r'], #027C LATIN SMALL LETTER R WITH LONG LEG
'ɽ' => [ 'ɽ', 'r'], #027D LATIN SMALL LETTER R WITH TAIL
'ɾ' => [ 'ɾ', 'r'], #027E LATIN SMALL LETTER R WITH FISHHOOK
'ɿ' => [ 'ɿ', 'r'], #027F LATIN SMALL LETTER REVERSED R WITH FISHHOOK
'ʀ' => [ 'ʀ', 'r'], #0280 LATIN LETTER SMALL CAPITAL R
'ʂ' => [ 'ʂ', 's'], #0282 LATIN SMALL LETTER S WITH HOOK
'ʄ' => [ 'ʄ', 'j'], #0284 LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK
'ʇ' => [ 'ʇ', 't'], #0287 LATIN SMALL LETTER TURNED T
'ʈ' => [ 'ʈ', 't'], #0288 LATIN SMALL LETTER T WITH RETROFLEX HOOK
'ʉ' => [ 'ʉ', 'u'], #0289 LATIN SMALL LETTER U BAR
'ʋ' => [ 'ʋ', 'v'], #028B LATIN SMALL LETTER V WITH HOOK
'ʌ' => [ 'ʌ', 'v'], #028C LATIN SMALL LETTER TURNED V
'ʍ' => [ 'ʍ', 'w'], #028D LATIN SMALL LETTER TURNED W
'ʎ' => [ 'ʎ', 'y'], #028E LATIN SMALL LETTER TURNED Y
'ʏ' => [ 'ʏ', 'y'], #028F LATIN LETTER SMALL CAPITAL Y
'ʐ' => [ 'ʐ', 'z'], #0290 LATIN SMALL LETTER Z WITH RETROFLEX HOOK
'ʑ' => [ 'ʑ', 'z'], #0291 LATIN SMALL LETTER Z WITH CURL
'ʙ' => [ 'ʙ', 'b'], #0299 LATIN LETTER SMALL CAPITAL B
'ʚ' => [ 'ʚ', 'e'], #029A LATIN SMALL LETTER CLOSED OPEN E
'ʛ' => [ 'ʛ', 'g'], #029B LATIN LETTER SMALL CAPITAL G WITH HOOK
'ʜ' => [ 'ʜ', 'h'], #029C LATIN LETTER SMALL CAPITAL H
'ʝ' => [ 'ʝ', 'j'], #029D LATIN SMALL LETTER J WITH CROSSED-TAIL
'ʞ' => [ 'ʞ', 'k'], #029E LATIN SMALL LETTER TURNED K
'ʟ' => [ 'ʟ', 'l'], #029F LATIN LETTER SMALL CAPITAL L
'ʠ' => [ 'ʠ', 'q'], #02A0 LATIN SMALL LETTER Q WITH HOOK
'ʣ' => [ 'ʣ', 'dz'], #02A3 LATIN SMALL LETTER DZ DIGRAPH
'ʥ' => [ 'ʥ', 'dz'], #02A5 LATIN SMALL LETTER DZ DIGRAPH WITH CURL
'ʦ' => [ 'ʦ', 'ts'], #02A6 LATIN SMALL LETTER TS DIGRAPH
'ʨ' => [ 'ʨ', 'tc'], #02A8 LATIN SMALL LETTER TC DIGRAPH WITH CURL
'ʪ' => [ 'ʪ', 'ls'], #02AA LATIN SMALL LETTER LS DIGRAPH
'ʫ' => [ 'ʫ', 'lz'], #02AB LATIN SMALL LETTER LZ DIGRAPH
'ʮ' => [ 'ʮ', 'h'], #02AE LATIN SMALL LETTER TURNED H WITH FISHHOOK 
'ʯ' => [ 'ʯ', 'h'], #02AF LATIN SMALL LETTER TURNED H WITH FISHHOOK AND TAIL
'֊' => [ '-', '-'], #058A ARMENIAN HYPHEN
'᠆' => [ '-', '-'], #1806 MONGOLIAN TODO SOFT HYPHEN
'ᴀ' => [ 'ᴀ', 'a'], #1D00 LATIN LETTER SMALL CAPITAL A
'ᴁ' => [ 'ᴁ', 'ae'], #1D01 LATIN LETTER SMALL CAPITAL AE
'ᴂ' => [ 'ᴂ', 'ae'], #1D02 LATIN SMALL LETTER TURNED AE
'ᴃ' => [ 'ᴃ', 'b'], #1D03 LATIN LETTER SMALL CAPITAL BARRED B
'ᴄ' => [ 'ᴄ', 'c'], #1D04 LATIN LETTER SMALL CAPITAL C
'ᴅ' => [ 'ᴅ', 'd'], #1D05 LATIN LETTER SMALL CAPITAL D
'ᴇ' => [ 'ᴇ', 'e'], #1D07 LATIN LETTER SMALL CAPITAL E
'ᴈ' => [ 'ᴈ', 'e'], #1D08 LATIN SMALL LETTER TURNED OPEN E
'ᴉ' => [ 'ᴉ', 'i'], #1D09 LATIN SMALL LETTER TURNED I
'ᴊ' => [ 'ᴊ', 'j'], #1D0A LATIN LETTER SMALL CAPITAL J
'ᴋ' => [ 'ᴋ', 'k'], #1D0B LATIN LETTER SMALL CAPITAL K
'ᴌ' => [ 'ᴌ', 'l'], #1D0C LATIN LETTER SMALL CAPITAL L WITH STROKE
'ᴍ' => [ 'ᴍ', 'm'], #1D0D LATIN LETTER SMALL CAPITAL M
'ᴎ' => [ 'ᴎ', 'n'], #1D0E LATIN LETTER SMALL CAPITAL REVERSED N
'ᴏ' => [ 'ᴏ', 'o'], #1D0F LATIN LETTER SMALL CAPITAL O
'ᴐ' => [ 'ᴐ', 'o'], #1D10 LATIN LETTER SMALL CAPITAL OPEN O
'ᴑ' => [ 'ᴑ', 'o'], #1D11 LATIN SMALL LETTER SIDEWAYS O
'ᴒ' => [ 'ᴒ', 'o'], #1D12 LATIN SMALL LETTER SIDEWAYS OPEN O
'ᴓ' => [ 'ᴓ', 'o'], #1D13 LATIN SMALL LETTER SIDEWAYS O WITH STROKE
'ᴔ' => [ 'ᴔ', 'oe'], #1D14 LATIN SMALL LETTER TURNED OE
'ᴕ' => [ 'ᴕ', 'ou'], #1D15 LATIN LETTER SMALL CAPITAL OU
'ᴘ' => [ 'ᴘ', 'p'], #1D18 LATIN LETTER SMALL CAPITAL P
'ᴙ' => [ 'ᴙ', 'r'], #1D19 LATIN LETTER SMALL CAPITAL REVERSED R
'ᴚ' => [ 'ᴚ', 'r'], #1D1A LATIN LETTER SMALL CAPITAL TURNED R
'ᴛ' => [ 'ᴛ', 't'], #1D1B LATIN LETTER SMALL CAPITAL T
'ᴜ' => [ 'ᴜ', 'u'], #1D1C LATIN LETTER SMALL CAPITAL U
'ᴝ' => [ 'ᴝ', 'u'], #1D1D LATIN SMALL LETTER SIDEWAYS U
'ᴟ' => [ 'ᴟ', 'm'], #1D1F LATIN SMALL LETTER SIDEWAYS TURNED M
'ᴠ' => [ 'ᴠ', 'v'], #1D20 LATIN LETTER SMALL CAPITAL V
'ᴡ' => [ 'ᴡ', 'w'], #1D21 LATIN LETTER SMALL CAPITAL W
'ᴢ' => [ 'ᴢ', 'z'], #1D22 LATIN LETTER SMALL CAPITAL Z
'ᵢ' => [ 'ᵢ', 'i'], #1D62 LATIN SUBSCRIPT SMALL LETTER I
'ᵣ' => [ 'ᵣ', 'r'], #1D63 LATIN SUBSCRIPT SMALL LETTER R
'ᵤ' => [ 'ᵤ', 'u'], #1D64 LATIN SUBSCRIPT SMALL LETTER U
'ᵥ' => [ 'ᵥ', 'v'], #1D65 LATIN SUBSCRIPT SMALL LETTER V
'ᵫ' => [ 'ᵫ', 'ue'], #1D6B LATIN SMALL LETTER UE
'Ḁ' => [ 'ḁ', 'a'], #1E00 LATIN CAPITAL LETTER A WITH RING BELOW
'ḁ' => [ 'ḁ', 'a'], #1E01 LATIN SMALL LETTER A WITH RING BELOW
'Ḃ' => [ 'ḃ', 'b'], #1E02 LATIN CAPITAL LETTER B WITH DOT ABOVE
'ḃ' => [ 'ḃ', 'b'], #1E03 LATIN SMALL LETTER B WITH DOT ABOVE
'Ḅ' => [ 'ḅ', 'b'], #1E04 LATIN CAPITAL LETTER B WITH DOT BELOW
'ḅ' => [ 'ḅ', 'b'], #1E05 LATIN SMALL LETTER B WITH DOT BELOW
'Ḇ' => [ 'ḇ', 'b'], #1E06 LATIN CAPITAL LETTER B WITH LINE BELOW
'ḇ' => [ 'ḇ', 'b'], #1E07 LATIN SMALL LETTER B WITH LINE BELOW
'Ḉ' => [ 'ḉ', 'c'], #1E08 LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE
'ḉ' => [ 'ḉ', 'c'], #1E09 LATIN SMALL LETTER C WITH CEDILLA AND ACUTE
'Ḋ' => [ 'ḋ', 'd'], #1E0A LATIN CAPITAL LETTER D WITH DOT ABOVE
'ḋ' => [ 'ḋ', 'd'], #1E0B LATIN SMALL LETTER D WITH DOT ABOVE
'Ḍ' => [ 'ḍ', 'd'], #1E0C LATIN CAPITAL LETTER D WITH DOT BELOW
'ḍ' => [ 'ḍ', 'd'], #1E0D LATIN SMALL LETTER D WITH DOT BELOW
'Ḏ' => [ 'ḏ', 'd'], #1E0E LATIN CAPITAL LETTER D WITH LINE BELOW
'ḏ' => [ 'ḏ', 'd'], #1E0F LATIN SMALL LETTER D WITH LINE BELOW
'Ḑ' => [ 'ḑ', 'd'], #1E10 LATIN CAPITAL LETTER D WITH CEDILLA
'ḑ' => [ 'ḑ', 'd'], #1E11 LATIN SMALL LETTER D WITH CEDILLA
'Ḓ' => [ 'ḓ', 'd'], #1E12 LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW
'ḓ' => [ 'ḓ', 'd'], #1E13 LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW
'Ḕ' => [ 'ḕ', 'e'], #1E14 LATIN CAPITAL LETTER E WITH MACRON AND GRAVE
'ḕ' => [ 'ḕ', 'e'], #1E15 LATIN SMALL LETTER E WITH MACRON AND GRAVE
'Ḗ' => [ 'ḗ', 'e'], #1E16 LATIN CAPITAL LETTER E WITH MACRON AND ACUTE
'ḗ' => [ 'ḗ', 'e'], #1E17 LATIN SMALL LETTER E WITH MACRON AND ACUTE
'Ḙ' => [ 'ḙ', 'e'], #1E18 LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW
'ḙ' => [ 'ḙ', 'e'], #1E19 LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW
'Ḛ' => [ 'ḛ', 'e'], #1E1A LATIN CAPITAL LETTER E WITH TILDE BELOW
'ḛ' => [ 'ḛ', 'e'], #1E1B LATIN SMALL LETTER E WITH TILDE BELOW
'Ḝ' => [ 'ḝ', 'e'], #1E1C LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE
'ḝ' => [ 'ḝ', 'e'], #1E1D LATIN SMALL LETTER E WITH CEDILLA AND BREVE
'Ḟ' => [ 'ḟ', 'f'], #1E1E LATIN CAPITAL LETTER F WITH DOT ABOVE
'ḟ' => [ 'ḟ', 'f'], #1E1F LATIN SMALL LETTER F WITH DOT ABOVE
'Ḡ' => [ 'ḡ', 'g'], #1E20 LATIN CAPITAL LETTER G WITH MACRON
'ḡ' => [ 'ḡ', 'g'], #1E21 LATIN SMALL LETTER G WITH MACRON
'Ḣ' => [ 'ḣ', 'h'], #1E22 LATIN CAPITAL LETTER H WITH DOT ABOVE
'ḣ' => [ 'ḣ', 'h'], #1E23 LATIN SMALL LETTER H WITH DOT ABOVE
'Ḥ' => [ 'ḥ', 'h'], #1E24 LATIN CAPITAL LETTER H WITH DOT BELOW
'ḥ' => [ 'ḥ', 'h'], #1E25 LATIN SMALL LETTER H WITH DOT BELOW
'Ḧ' => [ 'ḧ', 'h'], #1E26 LATIN CAPITAL LETTER H WITH DIAERESIS
'ḧ' => [ 'ḧ', 'h'], #1E27 LATIN SMALL LETTER H WITH DIAERESIS
'Ḩ' => [ 'ḩ', 'h'], #1E28 LATIN CAPITAL LETTER H WITH CEDILLA
'ḩ' => [ 'ḩ', 'h'], #1E29 LATIN SMALL LETTER H WITH CEDILLA
'Ḫ' => [ 'ḫ', 'h'], #1E2A LATIN CAPITAL LETTER H WITH BREVE BELOW
'ḫ' => [ 'ḫ', 'h'], #1E2B LATIN SMALL LETTER H WITH BREVE BELOW
'Ḭ' => [ 'ḭ', 'i'], #1E2C LATIN CAPITAL LETTER I WITH TILDE BELOW
'ḭ' => [ 'ḭ', 'i'], #1E2D LATIN SMALL LETTER I WITH TILDE BELOW
'Ḯ' => [ 'ḯ', 'i'], #1E2E LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE
'ḯ' => [ 'ḯ', 'i'], #1E2F LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE
'Ḱ' => [ 'ḱ', 'k'], #1E30 LATIN CAPITAL LETTER K WITH ACUTE
'ḱ' => [ 'ḱ', 'k'], #1E31 LATIN SMALL LETTER K WITH ACUTE
'Ḳ' => [ 'ḳ', 'k'], #1E32 LATIN CAPITAL LETTER K WITH DOT BELOW
'ḳ' => [ 'ḳ', 'k'], #1E33 LATIN SMALL LETTER K WITH DOT BELOW
'Ḵ' => [ 'ḵ', 'k'], #1E34 LATIN CAPITAL LETTER K WITH LINE BELOW
'ḵ' => [ 'ḵ', 'k'], #1E35 LATIN SMALL LETTER K WITH LINE BELOW
'Ḷ' => [ 'ḷ', 'l'], #1E36 LATIN CAPITAL LETTER L WITH DOT BELOW
'ḷ' => [ 'ḷ', 'l'], #1E37 LATIN SMALL LETTER L WITH DOT BELOW
'Ḹ' => [ 'ḹ', 'l'], #1E38 LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON
'ḹ' => [ 'ḹ', 'l'], #1E39 LATIN SMALL LETTER L WITH DOT BELOW AND MACRON
'Ḻ' => [ 'ḻ', 'l'], #1E3A LATIN CAPITAL LETTER L WITH LINE BELOW
'ḻ' => [ 'ḻ', 'l'], #1E3B LATIN SMALL LETTER L WITH LINE BELOW
'Ḽ' => [ 'ḽ', 'l'], #1E3C LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW
'ḽ' => [ 'ḽ', 'l'], #1E3D LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW
'Ḿ' => [ 'ḿ', 'm'], #1E3E LATIN CAPITAL LETTER M WITH ACUTE
'ḿ' => [ 'ḿ', 'm'], #1E3F LATIN SMALL LETTER M WITH ACUTE
'Ṁ' => [ 'ṁ', 'm'], #1E40 LATIN CAPITAL LETTER M WITH DOT ABOVE
'ṁ' => [ 'ṁ', 'm'], #1E41 LATIN SMALL LETTER M WITH DOT ABOVE
'Ṃ' => [ 'ṃ', 'm'], #1E42 LATIN CAPITAL LETTER M WITH DOT BELOW
'ṃ' => [ 'ṃ', 'm'], #1E43 LATIN SMALL LETTER M WITH DOT BELOW
'Ṅ' => [ 'ṅ', 'n'], #1E44 LATIN CAPITAL LETTER N WITH DOT ABOVE
'ṅ' => [ 'ṅ', 'n'], #1E45 LATIN SMALL LETTER N WITH DOT ABOVE
'Ṇ' => [ 'ṇ', 'n'], #1E46 LATIN CAPITAL LETTER N WITH DOT BELOW
'ṇ' => [ 'ṇ', 'n'], #1E47 LATIN SMALL LETTER N WITH DOT BELOW
'Ṉ' => [ 'ṉ', 'n'], #1E48 LATIN CAPITAL LETTER N WITH LINE BELOW
'ṉ' => [ 'ṉ', 'n'], #1E49 LATIN SMALL LETTER N WITH LINE BELOW
'Ṋ' => [ 'ṋ', 'n'], #1E4A LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW
'ṋ' => [ 'ṋ', 'n'], #1E4B LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW
'Ṍ' => [ 'ṍ', 'o'], #1E4C LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
'ṍ' => [ 'ṍ', 'o'], #1E4D LATIN SMALL LETTER O WITH TILDE AND ACUTE
'Ṏ' => [ 'ṏ', 'o'], #1E4E LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
'ṏ' => [ 'ṏ', 'o'], #1E4F LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
'Ṑ' => [ 'ṑ', 'o'], #1E50 LATIN CAPITAL LETTER O WITH MACRON AND GRAVE
'ṑ' => [ 'ṑ', 'o'], #1E51 LATIN SMALL LETTER O WITH MACRON AND GRAVE
'Ṓ' => [ 'ṓ', 'o'], #1E52 LATIN CAPITAL LETTER O WITH MACRON AND ACUTE
'ṓ' => [ 'ṓ', 'o'], #1E53 LATIN SMALL LETTER O WITH MACRON AND ACUTE
'Ṕ' => [ 'ṕ', 'p'], #1E54 LATIN CAPITAL LETTER P WITH ACUTE
'ṕ' => [ 'ṕ', 'p'], #1E55 LATIN SMALL LETTER P WITH ACUTE
'Ṗ' => [ 'ṗ', 'p'], #1E56 LATIN CAPITAL LETTER P WITH DOT ABOVE
'ṗ' => [ 'ṗ', 'p'], #1E57 LATIN SMALL LETTER P WITH DOT ABOVE
'Ṙ' => [ 'ṙ', 'r'], #1E58 LATIN CAPITAL LETTER R WITH DOT ABOVE
'ṙ' => [ 'ṙ', 'r'], #1E59 LATIN SMALL LETTER R WITH DOT ABOVE
'Ṛ' => [ 'ṛ', 'r'], #1E5A LATIN CAPITAL LETTER R WITH DOT BELOW
'ṛ' => [ 'ṛ', 'r'], #1E5B LATIN SMALL LETTER R WITH DOT BELOW
'Ṝ' => [ 'ṝ', 'r'], #1E5C LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON
'ṝ' => [ 'ṝ', 'r'], #1E5D LATIN SMALL LETTER R WITH DOT BELOW AND MACRON
'Ṟ' => [ 'ṟ', 'r'], #1E5E LATIN CAPITAL LETTER R WITH LINE BELOW
'ṟ' => [ 'ṟ', 'r'], #1E5F LATIN SMALL LETTER R WITH LINE BELOW
'Ṡ' => [ 'ṡ', 's'], #1E60 LATIN CAPITAL LETTER S WITH DOT ABOVE
'ṡ' => [ 'ṡ', 's'], #1E61 LATIN SMALL LETTER S WITH DOT ABOVE
'Ṣ' => [ 'ṣ', 's'], #1E62 LATIN CAPITAL LETTER S WITH DOT BELOW
'ṣ' => [ 'ṣ', 's'], #1E63 LATIN SMALL LETTER S WITH DOT BELOW
'Ṥ' => [ 'ṥ', 's'], #1E64 LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE
'ṥ' => [ 'ṥ', 's'], #1E65 LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE
'Ṧ' => [ 'ṧ', 's'], #1E66 LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE
'ṧ' => [ 'ṧ', 's'], #1E67 LATIN SMALL LETTER S WITH CARON AND DOT ABOVE
'Ṩ' => [ 'ṩ', 's'], #1E68 LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE
'ṩ' => [ 'ṩ', 's'], #1E69 LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE
'Ṫ' => [ 'ṫ', 't'], #1E6A LATIN CAPITAL LETTER T WITH DOT ABOVE
'ṫ' => [ 'ṫ', 't'], #1E6B LATIN SMALL LETTER T WITH DOT ABOVE
'Ṭ' => [ 'ṭ', 't'], #1E6C LATIN CAPITAL LETTER T WITH DOT BELOW
'ṭ' => [ 'ṭ', 't'], #1E6D LATIN SMALL LETTER T WITH DOT BELOW
'Ṯ' => [ 'ṯ', 't'], #1E6E LATIN CAPITAL LETTER T WITH LINE BELOW
'ṯ' => [ 'ṯ', 't'], #1E6F LATIN SMALL LETTER T WITH LINE BELOW
'Ṱ' => [ 'ṱ', 't'], #1E70 LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW
'ṱ' => [ 'ṱ', 't'], #1E71 LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW
'Ṳ' => [ 'ṳ', 'u'], #1E72 LATIN CAPITAL LETTER U WITH DIAERESIS BELOW
'ṳ' => [ 'ṳ', 'u'], #1E73 LATIN SMALL LETTER U WITH DIAERESIS BELOW
'Ṵ' => [ 'ṵ', 'u'], #1E74 LATIN CAPITAL LETTER U WITH TILDE BELOW
'ṵ' => [ 'ṵ', 'u'], #1E75 LATIN SMALL LETTER U WITH TILDE BELOW
'Ṷ' => [ 'ṷ', 'u'], #1E76 LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW
'ṷ' => [ 'ṷ', 'u'], #1E77 LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW
'Ṹ' => [ 'ṹ', 'u'], #1E78 LATIN CAPITAL LETTER U WITH TILDE AND ACUTE
'ṹ' => [ 'ṹ', 'u'], #1E79 LATIN SMALL LETTER U WITH TILDE AND ACUTE
'Ṻ' => [ 'ṻ', 'u'], #1E7A LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS
'ṻ' => [ 'ṻ', 'u'], #1E7B LATIN SMALL LETTER U WITH MACRON AND DIAERESIS
'Ṽ' => [ 'ṽ', 'v'], #1E7C LATIN CAPITAL LETTER V WITH TILDE
'ṽ' => [ 'ṽ', 'v'], #1E7D LATIN SMALL LETTER V WITH TILDE
'Ṿ' => [ 'ṿ', 'v'], #1E7E LATIN CAPITAL LETTER V WITH DOT BELOW
'ṿ' => [ 'ṿ', 'v'], #1E7F LATIN SMALL LETTER V WITH DOT BELOW
'Ẁ' => [ 'ẁ', 'w'], #1E80 LATIN CAPITAL LETTER W WITH GRAVE
'ẁ' => [ 'ẁ', 'w'], #1E81 LATIN SMALL LETTER W WITH GRAVE
'Ẃ' => [ 'ẃ', 'w'], #1E82 LATIN CAPITAL LETTER W WITH ACUTE
'ẃ' => [ 'ẃ', 'w'], #1E83 LATIN SMALL LETTER W WITH ACUTE
'Ẅ' => [ 'ẅ', 'w'], #1E84 LATIN CAPITAL LETTER W WITH DIAERESIS
'ẅ' => [ 'ẅ', 'w'], #1E85 LATIN SMALL LETTER W WITH DIAERESIS
'Ẇ' => [ 'ẇ', 'w'], #1E86 LATIN CAPITAL LETTER W WITH DOT ABOVE
'ẇ' => [ 'ẇ', 'w'], #1E87 LATIN SMALL LETTER W WITH DOT ABOVE
'Ẉ' => [ 'ẉ', 'w'], #1E88 LATIN CAPITAL LETTER W WITH DOT BELOW
'ẉ' => [ 'ẉ', 'w'], #1E89 LATIN SMALL LETTER W WITH DOT BELOW
'Ẋ' => [ 'ẋ', 'x'], #1E8A LATIN CAPITAL LETTER X WITH DOT ABOVE
'ẋ' => [ 'ẋ', 'x'], #1E8B LATIN SMALL LETTER X WITH DOT ABOVE
'Ẍ' => [ 'ẍ', 'x'], #1E8C LATIN CAPITAL LETTER X WITH DIAERESIS
'ẍ' => [ 'ẍ', 'x'], #1E8D LATIN SMALL LETTER X WITH DIAERESIS
'Ẏ' => [ 'ẏ', 'y'], #1E8E LATIN CAPITAL LETTER Y WITH DOT ABOVE
'ẏ' => [ 'ẏ', 'y'], #1E8F LATIN SMALL LETTER Y WITH DOT ABOVE
'Ẑ' => [ 'ẑ', 'z'], #1E90 LATIN CAPITAL LETTER Z WITH CIRCUMFLEX
'ẑ' => [ 'ẑ', 'z'], #1E91 LATIN SMALL LETTER Z WITH CIRCUMFLEX
'Ẓ' => [ 'ẓ', 'z'], #1E92 LATIN CAPITAL LETTER Z WITH DOT BELOW
'ẓ' => [ 'ẓ', 'z'], #1E93 LATIN SMALL LETTER Z WITH DOT BELOW
'Ẕ' => [ 'ẕ', 'z'], #1E94 LATIN CAPITAL LETTER Z WITH LINE BELOW
'ẕ' => [ 'ẕ', 'z'], #1E95 LATIN SMALL LETTER Z WITH LINE BELOW
'ẖ' => [ 'ẖ', 'h'], #1E96 LATIN SMALL LETTER H WITH LINE BELOW
'ẗ' => [ 'ẗ', 't'], #1E97 LATIN SMALL LETTER T WITH DIAERESIS
'ẘ' => [ 'ẘ', 'w'], #1E98 LATIN SMALL LETTER W WITH RING ABOVE
'ẙ' => [ 'ẙ', 'y'], #1E99 LATIN SMALL LETTER Y WITH RING ABOVE
'ẚ' => [ 'ẚ', 'a'], #1E9A LATIN SMALL LETTER A WITH RIGHT HALF RING
'ẛ' => [ 'ẛ', 's'], #1E9B LATIN SMALL LETTER LONG S WITH DOT ABOVE
'Ạ' => [ 'ạ', 'a'], #1EA0 LATIN CAPITAL LETTER A WITH DOT BELOW
'ạ' => [ 'ạ', 'a'], #1EA1 LATIN SMALL LETTER A WITH DOT BELOW
'Ả' => [ 'ả', 'a'], #1EA2 LATIN CAPITAL LETTER A WITH HOOK ABOVE
'ả' => [ 'ả', 'a'], #1EA3 LATIN SMALL LETTER A WITH HOOK ABOVE
'Ấ' => [ 'ấ', 'a'], #1EA4 LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE
'ấ' => [ 'ấ', 'a'], #1EA5 LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE
'Ầ' => [ 'ầ', 'a'], #1EA6 LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE
'ầ' => [ 'ầ', 'a'], #1EA7 LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE
'Ẩ' => [ 'ẩ', 'a'], #1EA8 LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
'ẩ' => [ 'ẩ', 'a'], #1EA9 LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
'Ẫ' => [ 'ẫ', 'a'], #1EAA LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE
'ẫ' => [ 'ẫ', 'a'], #1EAB LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE
'Ậ' => [ 'ậ', 'a'], #1EAC LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW
'ậ' => [ 'ậ', 'a'], #1EAD LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW
'Ắ' => [ 'ắ', 'a'], #1EAE LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
'ắ' => [ 'ắ', 'a'], #1EAF LATIN SMALL LETTER A WITH BREVE AND ACUTE
'Ằ' => [ 'ằ', 'a'], #1EB0 LATIN CAPITAL LETTER A WITH BREVE AND GRAVE
'ằ' => [ 'ằ', 'a'], #1EB1 LATIN SMALL LETTER A WITH BREVE AND GRAVE
'Ẳ' => [ 'ẳ', 'a'], #1EB2 LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE
'ẳ' => [ 'ẳ', 'a'], #1EB3 LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE
'Ẵ' => [ 'ẵ', 'a'], #1EB4 LATIN CAPITAL LETTER A WITH BREVE AND TILDE
'ẵ' => [ 'ẵ', 'a'], #1EB5 LATIN SMALL LETTER A WITH BREVE AND TILDE
'Ặ' => [ 'ặ', 'a'], #1EB6 LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW
'ặ' => [ 'ặ', 'a'], #1EB7 LATIN SMALL LETTER A WITH BREVE AND DOT BELOW
'Ẹ' => [ 'ẹ', 'e'], #1EB8 LATIN CAPITAL LETTER E WITH DOT BELOW
'ẹ' => [ 'ẹ', 'e'], #1EB9 LATIN SMALL LETTER E WITH DOT BELOW
'Ẻ' => [ 'ẻ', 'e'], #1EBA LATIN CAPITAL LETTER E WITH HOOK ABOVE
'ẻ' => [ 'ẻ', 'e'], #1EBB LATIN SMALL LETTER E WITH HOOK ABOVE
'Ẽ' => [ 'ẽ', 'e'], #1EBC LATIN CAPITAL LETTER E WITH TILDE
'ẽ' => [ 'ẽ', 'e'], #1EBD LATIN SMALL LETTER E WITH TILDE
'Ế' => [ 'ế', 'e'], #1EBE LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
'ế' => [ 'ế', 'e'], #1EBF LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
'Ề' => [ 'ề', 'e'], #1EC0 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
'ề' => [ 'ề', 'e'], #1EC1 LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
'Ể' => [ 'ể', 'e'], #1EC2 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
'ể' => [ 'ể', 'e'], #1EC3 LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
'Ễ' => [ 'ễ', 'e'], #1EC4 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
'ễ' => [ 'ễ', 'e'], #1EC5 LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
'Ệ' => [ 'ệ', 'e'], #1EC6 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
'ệ' => [ 'ệ', 'e'], #1EC7 LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
'Ỉ' => [ 'ỉ', 'i'], #1EC8 LATIN CAPITAL LETTER I WITH HOOK ABOVE
'ỉ' => [ 'ỉ', 'i'], #1EC9 LATIN SMALL LETTER I WITH HOOK ABOVE
'Ị' => [ 'ị', 'i'], #1ECA LATIN CAPITAL LETTER I WITH DOT BELOW
'ị' => [ 'ị', 'i'], #1ECB LATIN SMALL LETTER I WITH DOT BELOW
'Ọ' => [ 'ọ', 'o'], #1ECC LATIN CAPITAL LETTER O WITH DOT BELOW
'ọ' => [ 'ọ', 'o'], #1ECD LATIN SMALL LETTER O WITH DOT BELOW
'Ỏ' => [ 'ỏ', 'o'], #1ECE LATIN CAPITAL LETTER O WITH HOOK ABOVE
'ỏ' => [ 'ỏ', 'o'], #1ECF LATIN SMALL LETTER O WITH HOOK ABOVE
'Ố' => [ 'ố', 'o'], #1ED0 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
'ố' => [ 'ố', 'o'], #1ED1 LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
'Ồ' => [ 'ồ', 'o'], #1ED2 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
'ồ' => [ 'ồ', 'o'], #1ED3 LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
'Ổ' => [ 'ổ', 'o'], #1ED4 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
'ổ' => [ 'ổ', 'o'], #1ED5 LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
'Ỗ' => [ 'ỗ', 'o'], #1ED6 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
'ỗ' => [ 'ỗ', 'o'], #1ED7 LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
'Ộ' => [ 'ộ', 'o'], #1ED8 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
'ộ' => [ 'ộ', 'o'], #1ED9 LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
'Ớ' => [ 'ớ', 'o'], #1EDA LATIN CAPITAL LETTER O WITH HORN AND ACUTE
'ớ' => [ 'ớ', 'o'], #1EDB LATIN SMALL LETTER O WITH HORN AND ACUTE
'Ờ' => [ 'ờ', 'o'], #1EDC LATIN CAPITAL LETTER O WITH HORN AND GRAVE
'ờ' => [ 'ờ', 'o'], #1EDD LATIN SMALL LETTER O WITH HORN AND GRAVE
'Ở' => [ 'ở', 'o'], #1EDE LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE
'ở' => [ 'ở', 'o'], #1EDF LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE
'Ỡ' => [ 'ỡ', 'o'], #1EE0 LATIN CAPITAL LETTER O WITH HORN AND TILDE
'ỡ' => [ 'ỡ', 'o'], #1EE1 LATIN SMALL LETTER O WITH HORN AND TILDE
'Ợ' => [ 'ợ', 'o'], #1EE2 LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW
'ợ' => [ 'ợ', 'o'], #1EE3 LATIN SMALL LETTER O WITH HORN AND DOT BELOW
'Ụ' => [ 'ụ', 'u'], #1EE4 LATIN CAPITAL LETTER U WITH DOT BELOW
'ụ' => [ 'ụ', 'u'], #1EE5 LATIN SMALL LETTER U WITH DOT BELOW
'Ủ' => [ 'ủ', 'u'], #1EE6 LATIN CAPITAL LETTER U WITH HOOK ABOVE
'ủ' => [ 'ủ', 'u'], #1EE7 LATIN SMALL LETTER U WITH HOOK ABOVE
'Ứ' => [ 'ứ', 'u'], #1EE8 LATIN CAPITAL LETTER U WITH HORN AND ACUTE
'ứ' => [ 'ứ', 'u'], #1EE9 LATIN SMALL LETTER U WITH HORN AND ACUTE
'Ừ' => [ 'ừ', 'u'], #1EEA LATIN CAPITAL LETTER U WITH HORN AND GRAVE
'ừ' => [ 'ừ', 'u'], #1EEB LATIN SMALL LETTER U WITH HORN AND GRAVE
'Ử' => [ 'ử', 'u'], #1EEC LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE
'ử' => [ 'ử', 'u'], #1EED LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE
'Ữ' => [ 'ữ', 'u'], #1EEE LATIN CAPITAL LETTER U WITH HORN AND TILDE
'ữ' => [ 'ữ', 'u'], #1EEF LATIN SMALL LETTER U WITH HORN AND TILDE
'Ự' => [ 'ự', 'u'], #1EF0 LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW
'ự' => [ 'ự', 'u'], #1EF1 LATIN SMALL LETTER U WITH HORN AND DOT BELOW
'Ỳ' => [ 'ỳ', 'y'], #1EF2 LATIN CAPITAL LETTER Y WITH GRAVE
'ỳ' => [ 'ỳ', 'y'], #1EF3 LATIN SMALL LETTER Y WITH GRAVE
'Ỵ' => [ 'ỵ', 'y'], #1EF4 LATIN CAPITAL LETTER Y WITH DOT BELOW
'ỵ' => [ 'ỵ', 'y'], #1EF5 LATIN SMALL LETTER Y WITH DOT BELOW
'Ỷ' => [ 'ỷ', 'y'], #1EF6 LATIN CAPITAL LETTER Y WITH HOOK ABOVE
'ỷ' => [ 'ỷ', 'y'], #1EF7 LATIN SMALL LETTER Y WITH HOOK ABOVE
'Ỹ' => [ 'ỹ', 'y'], #1EF8 LATIN CAPITAL LETTER Y WITH TILDE
'ỹ' => [ 'ỹ', 'y'], #1EF9 LATIN SMALL LETTER Y WITH TILDE
'‐' => [ '-', '-'], #2010 HYPHEN
'‑' => [ '-', '-'], #2011 NON-BREAKING HYPHEN
'‒' => [ '-', '-'], #2012 FIGURE DASH
'–' => [ '-', '-'], #2013 EN DASH
'—' => [ '-', '-'], #2014 EM DASH
'―' => [ '-', '-'], #2015 HORIZONTAL BAR
'ⁱ' => [ 'ⁱ', 'i'], #2071 SUPERSCRIPT LATIN SMALL LETTER I
'ⁿ' => [ 'ⁿ', 'n'], #207F SUPERSCRIPT LATIN SMALL LETTER N
'⒜' => [ '⒜', 'a'], #249C PARENTHESIZED LATIN SMALL LETTER A
'⒝' => [ '⒝', 'b'], #249D PARENTHESIZED LATIN SMALL LETTER B
'⒞' => [ '⒞', 'c'], #249E PARENTHESIZED LATIN SMALL LETTER C
'⒟' => [ '⒟', 'd'], #249F PARENTHESIZED LATIN SMALL LETTER D
'⒠' => [ '⒠', 'e'], #24A0 PARENTHESIZED LATIN SMALL LETTER E
'⒡' => [ '⒡', 'f'], #24A1 PARENTHESIZED LATIN SMALL LETTER F
'⒢' => [ '⒢', 'g'], #24A2 PARENTHESIZED LATIN SMALL LETTER G
'⒣' => [ '⒣', 'h'], #24A3 PARENTHESIZED LATIN SMALL LETTER H
'⒤' => [ '⒤', 'i'], #24A4 PARENTHESIZED LATIN SMALL LETTER I
'⒥' => [ '⒥', 'j'], #24A5 PARENTHESIZED LATIN SMALL LETTER J
'⒦' => [ '⒦', 'k'], #24A6 PARENTHESIZED LATIN SMALL LETTER K
'⒧' => [ '⒧', 'l'], #24A7 PARENTHESIZED LATIN SMALL LETTER L
'⒨' => [ '⒨', 'm'], #24A8 PARENTHESIZED LATIN SMALL LETTER M
'⒩' => [ '⒩', 'n'], #24A9 PARENTHESIZED LATIN SMALL LETTER N
'⒪' => [ '⒪', 'o'], #24AA PARENTHESIZED LATIN SMALL LETTER O
'⒫' => [ '⒫', 'p'], #24AB PARENTHESIZED LATIN SMALL LETTER P
'⒬' => [ '⒬', 'q'], #24AC PARENTHESIZED LATIN SMALL LETTER Q
'⒭' => [ '⒭', 'r'], #24AD PARENTHESIZED LATIN SMALL LETTER R
'⒮' => [ '⒮', 's'], #24AE PARENTHESIZED LATIN SMALL LETTER S
'⒯' => [ '⒯', 't'], #24AF PARENTHESIZED LATIN SMALL LETTER T
'⒰' => [ '⒰', 'u'], #24B0 PARENTHESIZED LATIN SMALL LETTER U
'⒱' => [ '⒱', 'v'], #24B1 PARENTHESIZED LATIN SMALL LETTER V
'⒲' => [ '⒲', 'w'], #24B2 PARENTHESIZED LATIN SMALL LETTER W
'⒳' => [ '⒳', 'x'], #24B3 PARENTHESIZED LATIN SMALL LETTER X
'⒴' => [ '⒴', 'y'], #24B4 PARENTHESIZED LATIN SMALL LETTER Y
'⒵' => [ '⒵', 'z'], #24B5 PARENTHESIZED LATIN SMALL LETTER Z
'Ⓐ' => [ 'ⓐ', 'a'], #24B6 CIRCLED LATIN CAPITAL LETTER A
'Ⓑ' => [ 'ⓑ', 'b'], #24B7 CIRCLED LATIN CAPITAL LETTER B
'Ⓒ' => [ 'ⓒ', 'c'], #24B8 CIRCLED LATIN CAPITAL LETTER C
'Ⓓ' => [ 'ⓓ', 'd'], #24B9 CIRCLED LATIN CAPITAL LETTER D
'Ⓔ' => [ 'ⓔ', 'e'], #24BA CIRCLED LATIN CAPITAL LETTER E
'Ⓕ' => [ 'ⓕ', 'f'], #24BB CIRCLED LATIN CAPITAL LETTER F
'Ⓖ' => [ 'ⓖ', 'g'], #24BC CIRCLED LATIN CAPITAL LETTER G
'Ⓗ' => [ 'ⓗ', 'h'], #24BD CIRCLED LATIN CAPITAL LETTER H
'Ⓘ' => [ 'ⓘ', 'i'], #24BE CIRCLED LATIN CAPITAL LETTER I
'Ⓙ' => [ 'ⓙ', 'j'], #24BF CIRCLED LATIN CAPITAL LETTER J
'Ⓚ' => [ 'ⓚ', 'k'], #24C0 CIRCLED LATIN CAPITAL LETTER K
'Ⓛ' => [ 'ⓛ', 'l'], #24C1 CIRCLED LATIN CAPITAL LETTER L
'Ⓜ' => [ 'ⓜ', 'm'], #24C2 CIRCLED LATIN CAPITAL LETTER M
'Ⓝ' => [ 'ⓝ', 'n'], #24C3 CIRCLED LATIN CAPITAL LETTER N
'Ⓞ' => [ 'ⓞ', 'o'], #24C4 CIRCLED LATIN CAPITAL LETTER O
'Ⓟ' => [ 'ⓟ', 'p'], #24C5 CIRCLED LATIN CAPITAL LETTER P
'Ⓠ' => [ 'ⓠ', 'q'], #24C6 CIRCLED LATIN CAPITAL LETTER Q
'Ⓡ' => [ 'ⓡ', 'r'], #24C7 CIRCLED LATIN CAPITAL LETTER R
'Ⓢ' => [ 'ⓢ', 's'], #24C8 CIRCLED LATIN CAPITAL LETTER S
'Ⓣ' => [ 'ⓣ', 't'], #24C9 CIRCLED LATIN CAPITAL LETTER T
'Ⓤ' => [ 'ⓤ', 'u'], #24CA CIRCLED LATIN CAPITAL LETTER U
'Ⓥ' => [ 'ⓥ', 'v'], #24CB CIRCLED LATIN CAPITAL LETTER V
'Ⓦ' => [ 'ⓦ', 'w'], #24CC CIRCLED LATIN CAPITAL LETTER W
'Ⓧ' => [ 'ⓧ', 'x'], #24CD CIRCLED LATIN CAPITAL LETTER X
'Ⓨ' => [ 'ⓨ', 'y'], #24CE CIRCLED LATIN CAPITAL LETTER Y
'Ⓩ' => [ 'ⓩ', 'z'], #24CF CIRCLED LATIN CAPITAL LETTER Z
'ⓐ' => [ 'ⓐ', 'a'], #24D0 CIRCLED LATIN SMALL LETTER A
'ⓑ' => [ 'ⓑ', 'b'], #24D1 CIRCLED LATIN SMALL LETTER B
'ⓒ' => [ 'ⓒ', 'c'], #24D2 CIRCLED LATIN SMALL LETTER C
'ⓓ' => [ 'ⓓ', 'd'], #24D3 CIRCLED LATIN SMALL LETTER D
'ⓔ' => [ 'ⓔ', 'e'], #24D4 CIRCLED LATIN SMALL LETTER E
'ⓕ' => [ 'ⓕ', 'f'], #24D5 CIRCLED LATIN SMALL LETTER F
'ⓖ' => [ 'ⓖ', 'g'], #24D6 CIRCLED LATIN SMALL LETTER G
'ⓗ' => [ 'ⓗ', 'h'], #24D7 CIRCLED LATIN SMALL LETTER H
'ⓘ' => [ 'ⓘ', 'i'], #24D8 CIRCLED LATIN SMALL LETTER I
'ⓙ' => [ 'ⓙ', 'j'], #24D9 CIRCLED LATIN SMALL LETTER J
'ⓚ' => [ 'ⓚ', 'k'], #24DA CIRCLED LATIN SMALL LETTER K
'ⓛ' => [ 'ⓛ', 'l'], #24DB CIRCLED LATIN SMALL LETTER L
'ⓜ' => [ 'ⓜ', 'm'], #24DC CIRCLED LATIN SMALL LETTER M
'ⓝ' => [ 'ⓝ', 'n'], #24DD CIRCLED LATIN SMALL LETTER N
'ⓞ' => [ 'ⓞ', 'o'], #24DE CIRCLED LATIN SMALL LETTER O
'ⓟ' => [ 'ⓟ', 'p'], #24DF CIRCLED LATIN SMALL LETTER P
'ⓠ' => [ 'ⓠ', 'q'], #24E0 CIRCLED LATIN SMALL LETTER Q
'ⓡ' => [ 'ⓡ', 'r'], #24E1 CIRCLED LATIN SMALL LETTER R
'ⓢ' => [ 'ⓢ', 's'], #24E2 CIRCLED LATIN SMALL LETTER S
'ⓣ' => [ 'ⓣ', 't'], #24E3 CIRCLED LATIN SMALL LETTER T
'ⓤ' => [ 'ⓤ', 'u'], #24E4 CIRCLED LATIN SMALL LETTER U
'ⓥ' => [ 'ⓥ', 'v'], #24E5 CIRCLED LATIN SMALL LETTER V
'ⓦ' => [ 'ⓦ', 'w'], #24E6 CIRCLED LATIN SMALL LETTER W
'ⓧ' => [ 'ⓧ', 'x'], #24E7 CIRCLED LATIN SMALL LETTER X
'ⓨ' => [ 'ⓨ', 'y'], #24E8 CIRCLED LATIN SMALL LETTER Y
'ⓩ' => [ 'ⓩ', 'z'], #24E9 CIRCLED LATIN SMALL LETTER Z
'〜' => [ '-', '-'], #301C WAVE DASH
'〰' => [ '-', '-'], #3030 WAVY DASH
'゠' => [ '-', '-'], #30A0 KATAKANA-HIRAGANA DOUBLE HYPHEN
'ﬀ' => [ 'ﬀ', 'ff'], #FB00 LATIN SMALL LIGATURE FF
'ﬁ' => [ 'ﬁ', 'fi'], #FB01 LATIN SMALL LIGATURE FI
'ﬂ' => [ 'ﬂ', 'fl'], #FB02 LATIN SMALL LIGATURE FL
'ﬃ' => [ 'ﬃ', 'ffi'], #FB03 LATIN SMALL LIGATURE FFI
'ﬄ' => [ 'ﬄ', 'ffl'], #FB04 LATIN SMALL LIGATURE FFL
'ﬅ' => [ 'ﬅ', 'st'], #FB05 LATIN SMALL LIGATURE LONG S T
'ﬆ' => [ 'ﬆ', 'st'], #FB06 LATIN SMALL LIGATURE ST
'︱' => [ '-', '-'], #FE31 PRESENTATION FORM FOR VERTICAL EM DASH
'︲' => [ '-', '-'], #FE32 PRESENTATION FORM FOR VERTICAL EN DASH
'﹘' => [ '-', '-'], #FE58 SMALL EM DASH
'﹣' => [ '-', '-'], #FE63 SMALL HYPHEN-MINUS
'－' => [ '-', '-'], #FF0D FULLWIDTH HYPHEN-MINUS
'Ａ' => [ 'ａ', 'a'], #FF21 FULLWIDTH LATIN CAPITAL LETTER A
'Ｂ' => [ 'ｂ', 'b'], #FF22 FULLWIDTH LATIN CAPITAL LETTER B
'Ｃ' => [ 'ｃ', 'c'], #FF23 FULLWIDTH LATIN CAPITAL LETTER C
'Ｄ' => [ 'ｄ', 'd'], #FF24 FULLWIDTH LATIN CAPITAL LETTER D
'Ｅ' => [ 'ｅ', 'e'], #FF25 FULLWIDTH LATIN CAPITAL LETTER E
'Ｆ' => [ 'ｆ', 'f'], #FF26 FULLWIDTH LATIN CAPITAL LETTER F
'Ｇ' => [ 'ｇ', 'g'], #FF27 FULLWIDTH LATIN CAPITAL LETTER G
'Ｈ' => [ 'ｈ', 'h'], #FF28 FULLWIDTH LATIN CAPITAL LETTER H
'Ｉ' => [ 'ｉ', 'i'], #FF29 FULLWIDTH LATIN CAPITAL LETTER I
'Ｊ' => [ 'ｊ', 'j'], #FF2A FULLWIDTH LATIN CAPITAL LETTER J
'Ｋ' => [ 'ｋ', 'k'], #FF2B FULLWIDTH LATIN CAPITAL LETTER K
'Ｌ' => [ 'ｌ', 'l'], #FF2C FULLWIDTH LATIN CAPITAL LETTER L
'Ｍ' => [ 'ｍ', 'm'], #FF2D FULLWIDTH LATIN CAPITAL LETTER M
'Ｎ' => [ 'ｎ', 'n'], #FF2E FULLWIDTH LATIN CAPITAL LETTER N
'Ｏ' => [ 'ｏ', 'o'], #FF2F FULLWIDTH LATIN CAPITAL LETTER O
'Ｐ' => [ 'ｐ', 'p'], #FF30 FULLWIDTH LATIN CAPITAL LETTER P
'Ｑ' => [ 'ｑ', 'q'], #FF31 FULLWIDTH LATIN CAPITAL LETTER Q
'Ｒ' => [ 'ｒ', 'r'], #FF32 FULLWIDTH LATIN CAPITAL LETTER R
'Ｓ' => [ 'ｓ', 's'], #FF33 FULLWIDTH LATIN CAPITAL LETTER S
'Ｔ' => [ 'ｔ', 't'], #FF34 FULLWIDTH LATIN CAPITAL LETTER T
'Ｕ' => [ 'ｕ', 'u'], #FF35 FULLWIDTH LATIN CAPITAL LETTER U
'Ｖ' => [ 'ｖ', 'v'], #FF36 FULLWIDTH LATIN CAPITAL LETTER V
'Ｗ' => [ 'ｗ', 'w'], #FF37 FULLWIDTH LATIN CAPITAL LETTER W
'Ｘ' => [ 'ｘ', 'x'], #FF38 FULLWIDTH LATIN CAPITAL LETTER X
'Ｙ' => [ 'ｙ', 'y'], #FF39 FULLWIDTH LATIN CAPITAL LETTER Y
'Ｚ' => [ 'ｚ', 'z'], #FF3A FULLWIDTH LATIN CAPITAL LETTER Z
'ａ' => [ 'ａ', 'a'], #FF41 FULLWIDTH LATIN SMALL LETTER A
'ｂ' => [ 'ｂ', 'b'], #FF42 FULLWIDTH LATIN SMALL LETTER B
'ｃ' => [ 'ｃ', 'c'], #FF43 FULLWIDTH LATIN SMALL LETTER C
'ｄ' => [ 'ｄ', 'd'], #FF44 FULLWIDTH LATIN SMALL LETTER D
'ｅ' => [ 'ｅ', 'e'], #FF45 FULLWIDTH LATIN SMALL LETTER E
'ｆ' => [ 'ｆ', 'f'], #FF46 FULLWIDTH LATIN SMALL LETTER F
'ｇ' => [ 'ｇ', 'g'], #FF47 FULLWIDTH LATIN SMALL LETTER G
'ｈ' => [ 'ｈ', 'h'], #FF48 FULLWIDTH LATIN SMALL LETTER H
'ｉ' => [ 'ｉ', 'i'], #FF49 FULLWIDTH LATIN SMALL LETTER I
'ｊ' => [ 'ｊ', 'j'], #FF4A FULLWIDTH LATIN SMALL LETTER J
'ｋ' => [ 'ｋ', 'k'], #FF4B FULLWIDTH LATIN SMALL LETTER K
'ｌ' => [ 'ｌ', 'l'], #FF4C FULLWIDTH LATIN SMALL LETTER L
'ｍ' => [ 'ｍ', 'm'], #FF4D FULLWIDTH LATIN SMALL LETTER M
'ｎ' => [ 'ｎ', 'n'], #FF4E FULLWIDTH LATIN SMALL LETTER N
'ｏ' => [ 'ｏ', 'o'], #FF4F FULLWIDTH LATIN SMALL LETTER O
'ｐ' => [ 'ｐ', 'p'], #FF50 FULLWIDTH LATIN SMALL LETTER P
'ｑ' => [ 'ｑ', 'q'], #FF51 FULLWIDTH LATIN SMALL LETTER Q
'ｒ' => [ 'ｒ', 'r'], #FF52 FULLWIDTH LATIN SMALL LETTER R
'ｓ' => [ 'ｓ', 's'], #FF53 FULLWIDTH LATIN SMALL LETTER S
'ｔ' => [ 'ｔ', 't'], #FF54 FULLWIDTH LATIN SMALL LETTER T
'ｕ' => [ 'ｕ', 'u'], #FF55 FULLWIDTH LATIN SMALL LETTER U
'ｖ' => [ 'ｖ', 'v'], #FF56 FULLWIDTH LATIN SMALL LETTER V
'ｗ' => [ 'ｗ', 'w'], #FF57 FULLWIDTH LATIN SMALL LETTER W
'ｘ' => [ 'ｘ', 'x'], #FF58 FULLWIDTH LATIN SMALL LETTER X
'ｙ' => [ 'ｙ', 'y'], #FF59 FULLWIDTH LATIN SMALL LETTER Y
'ｚ' => [ 'ｚ', 'z'], #FF5A FULLWIDTH LATIN SMALL LETTER Z
};

######################################################################
#
# extract_words( $text )
#
#  This method is used when indexing a record, to decide what words
#  should be used as index words.
#  It is also used to decide which words to use when performing a
#  search. 
#
#  It returns references to 2 arrays, one of "good" words which should
#  be used, and one of "bad" words which should not.
#
######################################################################

sub extract_words
{
	my( $text ) = @_;
	# process string

	my %good = (); my %bad = (); my %ltn = ();
	my( $i, $len ),
	my $utext = utf8( "$text" ); # just in case it wasn't already.
	$len = $utext->length;
	my $word = ""; my $latin = "";
	# this is <= to include the last word
	for($i = 0; $i<=$len; ++$i )
	{
		my $dbl = $UnicodeConv->{ $utext->substr( $i, 1 ) };
		if( defined $dbl )
		{
			$word .= $dbl->[0]; $latin .= $dbl->[1];
		}
		elsif ( $word ne "" ) 
		# we have a ($word,$latin) pair to process
		{
			# erase leading and tailing dashes
			$word =~ s/-*$//; $word =~ s/^-*//;
			$latin =~ s/-*$//; $latin =~ s/^-*//;
			my $wlen= utf8($word)->length;
			next if( $wlen == 0 );
			my $ok = $wlen >= $FREETEXT_MIN_WORD_SIZE && $wlen < $FREETEXT_MAX_WORD_SIZE ;
			$ok = 0 if( $word =~ /^[0-9\-]*$/ );
			$ok = 0 if( $ok && $FREETEXT_STOP_WORDS->{$word} );
			$ok = 1 if( !$ok && $FREETEXT_ALWAYS_WORDS->{$word} );
			if( $ok )
			{
				$good{$word}++ unless( defined $ltn{$word} ) ;
				$ltn{$latin}++ unless( defined $good{$latin} );
			}
			else
			{
				$bad{$word}++;
			}
			$word=""; $latin="";
		}
	}
	# convert hash keys to arrays and return references
	# to these arrays.
	my( @g ) = keys %good; push @g, keys %ltn;
	my (@b ) = keys %bad;

	return( \@g, \@b );
}

# Return true to indicate the module loaded OK.
1;
